/* NOTE: This file was generated as an optimized version of "library.source.less" for the Theme Designer. */

/*!
 * OpenUI5
 * (c) Copyright 2009-2025 SAP SE or an SAP affiliate company.
 * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
 */

@import "../base/library.less";
@import "../../../../../Base/baseLib/sap_fiori_3/base.less"; /* ORIGINAL IMPORT PATH: "../../../../sap/ui/core/themes/sap_fiori_3/base.less" */

@import "../../../../sap/ui/core/themes/sap_fiori_3/global.less";

/* START "ActionListItem.less" */
/* ===================================== */
/* CSS for control sap.m/ActionListItem  */
/* Fiori 3 theme                         */
/* ===================================== */

html.sap-desktop .sapMList .sapMLIB.sapMALI:not(.sapMLIBActive) {
	padding: 0;
}

.sapMList .sapMLIB.sapMALI:focus {
	outline-offset: -0.2rem;
}

.sapMALI > .sapMLIBContent {
	line-height: 3rem;
}
/* END "ActionListItem.less" */

/* START "ActionSelect.less" */
/* =================================== */
/* CSS for control sap.m/ActionSelect  */
/* Fiori 3 theme                       */
/* =================================== */

/* ----------------------------- */
/* button                        */
/* ----------------------------- */

.sapMActionSelectPicker .sapMBtn {

	 .sapMBtnInner {
		border-top: 1px solid var(--sapList_BorderColor);
		border-bottom: 0;
		border-left: 0;
		border-right: 0;
		height: 2.5rem;
	 }

	 .sapMBtnContent {
		line-height: 2.4375rem;
	 }
}

.sapMActionSelectPicker .sapMBtn .sapMBtnInner {
	border-radius: 0;
}

/* override standard buttons inside the action select */

.sapMActionSelectPicker .sapMBtnDefault {
	background: var(--sapList_Background);
	border-color: var(--sapList_BorderColor);

	/* override the default text-shadow */
	text-shadow: none;
}

.sapMActionSelectPicker .sapMBtn,
.sapMActionSelectPicker .sapMBtn:hover > .sapMBtnHoverable:not(.sapMBtnActive) {
	border-color: var(--sapList_BorderColor);
}

html.sap-desktop .sapMActionSelectPicker .sapMBtn:not(.sapMBtnDisabled) .sapMBtnDefault:not(.sapMBtnActive):hover {
	background: var(--sapList_Hover_Background);
}

/* ======================================================================== */
/* CSS for control sap.m/ActionSelect Fiori 3 theme compact/condensed sizes */
/* ======================================================================== */

/* ----------------------------- */
/* button                        */
/* ----------------------------- */

.sapUiSizeCompact.sapMActionSelectPicker .sapMBtn,
.sapUiTableDataCell .sapUiSizeCondensed.sapMActionSelectPicker .sapMBtn {
	height: 2rem;
	padding: 0;
}

.sapUiSizeCompact.sapMActionSelectPicker .sapMBtnInner {
	height: 2rem;
	border-radius: 0;
	border: 0;
	border-top: 1px solid var(--sapList_BorderColor);

	.sapMBtnContent {
		line-height: 2rem;
	}
}
/* END "ActionSelect.less" */

/* START "ActionSheet.less" */
/* ================================== */
/* CSS for control sap.m/ActionSheet  */
/* Fiori 3  theme                     */
/* ================================== */

.sapMActionSheetDialog .sapMBar.sapMHeader-CTX > .sapMBarMiddle > .sapMBarPH > .sapMDialogTitle {
	color: var(--sapContent_ContrastTextColor);
	background: transparent;
}
/* END "ActionSheet.less" */

/* START "ActionTile.less" */
/* ================================== */
/* CSS for control sap.m/ActionTile  */
/* Fiori 3 theme                      */
/* ================================== */

.sapMAT:hover {
	box-shadow: none;
	transition: background 0.2s;
	background: var(--sapTile_Hover_Background);
}

.sapMAT:focus {

	.sapMATFocusDiv {
		border: var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor) !important;
	}

	.sapMGTFocusDiv {
		border: var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor) !important;
	}
}

.sapMAT:active {

	.sapMATFocusDiv {
		border: none;
	}
}
/* END "ActionTile.less" */

/* START "Avatar.less" */
/* ============================= */
/* CSS for control sap.m/Avatar  */
/* Fiori 3 theme                 */
/* ============================= */

.sapFAvatarInitialsHolder {
	color: var(--sapContent_ContrastTextColor);
}

.sapFAvatarIcon {
	color: var(--sapContent_ContrastIconColor);
}

.sapFAvatarSquare {
	border-radius: var(--sapElement_BorderCornerRadius);

	.sapFAvatarImageHolder {
		border-radius: var(--sapElement_BorderCornerRadius);
	}
}

.sapFAvatarXL {
	font-size: 3rem;
}

.sapFAvatarL {
	font-size: 2.25rem;
}

.sapFAvatarM {
	font-size: 1.5rem;
}

.sapFAvatarS {
	font-size: 1.125rem;
}

.sapFAvatarXS {
	font-size: 1rem;
}

.sapFAvatar.sapFAvatarInitials > .sapFAvatarInitialsHolder {
	font-size: inherit;
}
/* END "Avatar.less" */

/* START "Bar.less" */
/* ========================== */
/* CSS for control sap.m/Bar  */
/* Fiori 3 theme              */
/* ========================== */

.sapMBar {
	background-color: transparent;
	text-shadow: none;
}

.sapMBarRight,
.sapMBarPH {
	padding-right: 0.5rem;
}

.sapMBarLeft,
.sapMBarPH {
	padding-left: 0.5rem;
}

.sapMBar .sapMBarRight.sapMBarContainer > *:first-child,
.sapMBar .sapMBarLeft.sapMBarContainer > *:first-child,
.sapMBar .sapMBarMiddle .sapMBarContainer > *:first-child {
	margin: 0 0.25rem 0 0;
}

.sapMBar .sapMBarRight.sapMBarContainer > *:last-child,
.sapMBar .sapMBarLeft.sapMBarContainer > *:last-child,
.sapMBar .sapMBarMiddle .sapMBarContainer > *:last-child {
	margin: 0 0 0 0.25rem;
}

.sapMBar .sapMBarRight.sapMBarContainer > *:not(:first-child):not(:last-child),
.sapMBar .sapMBarLeft.sapMBarContainer > *:not(:first-child):not(:last-child),
.sapMBar .sapMBarMiddle .sapMBarContainer > *:not(:first-child):not(:last-child) {
	margin: 0 0.25rem;
}

.sapMBar .sapMBarRight.sapMBarContainer > *:first-child:last-child,
.sapMBar .sapMBarLeft.sapMBarContainer > *:first-child:last-child,
.sapMBar .sapMBarMiddle .sapMBarContainer > *:first-child:last-child {
	margin: 0;
}

.sapMBar {
	height: 2.75rem;
	line-height: 2.75rem;
}

.sapMBarLeft,
.sapMBarRight,
.sapMBarPH {
	height: 2.75rem;
	line-height: 2.75rem;
}

/* in Master page the bar should have different color */
.sapMSplitContainerMaster .sapMIBar .sapMHeader-CTX,
.sapMSplitContainerMaster .sapMIBar.sapMSubHeader-CTX {
	background-color: var(--sapGroup_ContentBackground);
}

/* in Master page the bar should have a different color shadow only if we don't have subHeader (e.g. another bar) */
.sapMSplitContainerMaster .sapMIBar .sapMHeader-CTX:only-of-type {
	box-shadow: inset 0 -0.0625rem var(--sapGroup_ContentBorderColor);
}

/* in Master page the bar should have a different color shadow */
.sapMSplitContainerMaster .sapMIBar.sapMSubHeader-CTX {
	box-shadow: inset 0 -0.0625rem var(--sapGroup_ContentBorderColor);
}

/* Bar Title Alignment */
.sapMBarTitleAlignAuto .sapMBarPH {
	justify-content: flex-start;
}

html[data-sap-ui-browser^="ff"].sap-desktop .sapMBarTitleAlignAuto .sapMBarPH {
	justify-content: start;
}
/* END "Bar.less" */

/* START "BusyDialog.less" */
/* ================================= */
/* CSS for control sap.m/BusyDialog  */
/* Fiori 3 theme                     */
/* ================================= */

@_sap_m_BusyDialog_IndicatorMargin: 1.5rem 0;
@_sap_m_BusyDialog_IndicatorMarginCompact: 1.5rem 0;
/* END "BusyDialog.less" */

/* START "BusyIndicator.less" */
/* ==================================== */
/* CSS for control sap.m/BusyIndicator  */
/* Fiori 3 theme                        */
/* ==================================== */

/* Background animation element */
.sapUiLocalBusyIndicatorAnimation > div::before {
	background: var(--sapContent_IconColor);
	animation-duration: 0ms;
}

/* Shadow animation element */
.sapUiLocalBusyIndicatorAnimation > div::after {
	box-shadow: inset 0 0 0 0 var(--sapContent_IconColor);
}
/* END "BusyIndicator.less" */

/* START "Button.less" */
/* ============================= */
/* CSS for control sap.m/Button  */
/* Fiori 3 theme                 */
/* ============================= */

@_sap_m_Button_EmphasizedFocusColor: var(--sapContent_FocusColor);

.sapMBtn {
	height: 2.75rem;
}

.sapMBtnEmphasized {
	font-weight: var(--sapButton_Emphasized_FontWeight);
}

.sapMIBar-CTX .sapMBtn:hover > .sapMBtnHoverable.sapMBtnEmphasized:not(.sapMBtnActive),
span.sapMBtnInner.sapMBtnEmphasized {
	text-shadow: none;
}

.sapMIBar-CTX .sapMBtn:hover > .sapMBtnHoverable.sapMBtnEmphasized:not(.sapMBtnActive) {
	color: var(--sapButton_Emphasized_Hover_TextColor);
	font-weight: var(--sapButton_Emphasized_FontWeight);

	.sapMBtnIcon {
		color: var(--sapButton_Emphasized_Hover_TextColor);
	}
}

/* --------------------- */
/* Inner area            */
/* --------------------- */
.sapMBtnInner {
	font-size: @sapMFontMediumSize;
	height: var(--sapElement_Height);
	min-width: 2.25rem;
	margin: 0;
	padding: 0;
	text-align: center;
	position: relative;
	border-radius: var(--sapButton_BorderCornerRadius);
	text-shadow: none;

	&.sapMBtnCritical,
	&.sapMBtnNegative,
	&.sapMBtnSuccess,
	&.sapMBtnNeutral {
		font-weight: bold;
	}
}

/* ------------------- */
/* Button Icon         */
/* ------------------- */
.sapMBtnIcon {
	width: 2.125rem;
	font-size: 1rem;
	line-height: 2.125rem;
}

.sapMBtnInner.sapMBtnText .sapMBtnIcon::before {
	width: 1rem;
	text-align: center;
	display: inline-block;
}

.sapMBtnInner.sapMBtnText .sapMBtnIcon {
	width: 1rem;
	min-width: 1rem;
	padding-right: 0.375rem;
	text-align: center;
}

.sapMBtnInner.sapMBtnText .sapMBtnIcon.sapMBtnIconRight {
	padding-right: 0;
	padding-left: 0.375rem;
}

.sapMBtnInner.sapMBtnText .sapMBtnIcon.sapMImg {
	height: 2.25rem;
	width: auto;
}

.sapMBtnInner .sapMBtnIcon.sapMImg {
	max-height: 2.125rem;
}

.sapUiSizeCompact .sapMBtnInner .sapMBtnIcon.sapMImg {
	max-height: 1.5rem;
}

/* ------------------- */
/* Content area        */
/* ------------------- */
.sapMBtnContent {
	line-height: 2.125rem;
}

.sapMBtnInner.sapMBtnText {
	padding-left: 0.5625rem;
	padding-right: 0.5625rem;
}

.sapMBtnIconLeft + .sapMBtnIconRight,
.sapMBtnIconLeft + .sapMBtnIconLeft {
	padding-right: 0.5625rem;
}

.sapMBtnGhost {
	color: var(--sapButton_TextColor);
	border: 0.0625rem solid var(--sapButton_BorderColor);
	background: var(--sapButton_Lite_Background);
}

.sapMBtnGhost.sapMBtnHoverable.sapMBtnActive {
	color: var(--sapButton_Active_TextColor);
	border-color: var(--sapButton_Active_BorderColor);
	background: var(--sapButton_Active_Background);
}

.sapUiSizeCompact {

	.sapMBtnIcon {
		margin-left: 0;
		margin-right: 0;
	}

	.sapMBtnInner.sapMBtnText {
		padding-left: 0.4375rem;
		padding-right: 0.4375rem;
	}

	.sapMBtnBack.sapMBtnIconFirst:not(.sapMBtnText) > .sapMBtnIconLeft:not(:last-child),
	.sapMBtnIconLeft + .sapMBtnIconRight,
	.sapMBtnIconLeft + .sapMBtnIconLeft,
	.sapMBtnInner .sapMBtnIcon :not(img) {
		padding-right: 0.4375rem;
	}

	.sapMBtnInner > img {
		margin: 0;
		padding: 0;
	}
}

/* ---------------------------------------------------------------------*/
/* Custom focus outline:                                                */
/* ---------------------------------------------------------------------*/

html.sap-desktop .sapMBtn:focus > .sapMFocusable {
	outline: 0.0625rem dotted var(--sapContent_FocusColor);
	outline-offset: -0.1875rem;
}

html.sap-desktop .sapMBtn:focus > .sapMBtnActive.sapMFocusable {
	outline-color: var(--sapContent_ContrastFocusColor);
}

html.sap-desktop .sapMBtn:focus > .sapMBtnCritical.sapMFocusable,
html.sap-desktop .sapMBtn:focus > .sapMBtnNegative.sapMFocusable,
html.sap-desktop .sapMBtn:focus > .sapMBtnSuccess.sapMFocusable,
html.sap-desktop .sapMBtn:focus > .sapMBtnNeutral.sapMFocusable {
	outline-color: var(--sapContent_ContrastFocusColor);
}

html.sap-desktop .sapMBtn:focus > .sapMBtnEmphasized.sapMFocusable {
	outline: .0625rem solid var(--sapContent_FocusColor);
}

html.sap-desktop .sapMBtn:focus > .sapMBtnEmphasized.sapMFocusable :not(.sapMBadgeIndicator) ::after {
	content: "";
	position: absolute;
	box-sizing: border-box;
	left: 0.0625rem;
	top: 0.0625rem;
	right: 0.0625rem;
	bottom: 0.0625rem;
	border: .0625rem dotted var(--sapContent_ContrastFocusColor);
	pointer-events: none
}

.sapMTB-Transparent-CTX .sapMBtnInner:not(.sapMToggleBtnPressed):not(.sapMBtnEmphasized):not(.sapMBtnAccept):not(.sapMBtnAttention):not(.sapMBtnReject):not(.sapMBtnActive):not(.sapMBtnGhost) {
	border-color: var(--sapButton_Lite_BorderColor);
}

/* ---------------------------------------------------------------------*/
/* Disabled, hover and active states:                                   */
/* ---------------------------------------------------------------------*/

.sapMBtnDisabled {
	opacity: var(--sapContent_DisabledOpacity);
}

/* ------------------------------------------------ */
/* Buttons in a Bar                                 */
/* (add separators, remove top/bottom border)       */
/* ------------------------------------------------ */

.sapMIBar-CTX .sapMBtnInner,
.sapMBar .sapMBtnInner,
.sapMHeader-CTX .sapMBtnInner,
.sapMFooter-CTX .sapMBtnInner {
	background: var(--sapButton_Lite_Background);
	border-color: var(--sapButton_Lite_BorderColor);
}

.sapMIBar-CTX .sapMBtnInner,
.sapMBar .sapMBtnInner {

	&.sapMBtnCritical {
		background: var(--sapCriticalElementColor);
		border-color: var(--sapCriticalElementColor);
	}

	&.sapMBtnNegative {
		background: var(--sapNegativeElementColor);
		border-color: var(--sapNegativeElementColor);
	}

	&.sapMBtnNeutral {
		background: var(--sapButton_Neutral_Background);
		border-color: var(--sapButton_Neutral_BorderColor);
	}

	&.sapMBtnSuccess {
		background: var(--sapPositiveElementColor);
		border-color: var(--sapPositiveElementColor);
	}
}

.sapMIBar-CTX .sapMBtnInner.sapMBtnGhost,
.sapMBar .sapMBtnInner.sapMBtnGhost,
.sapMHeader-CTX .sapMBtnInner.sapMBtnGhost,
.sapMFooter-CTX .sapMBtnInner.sapMBtnGhost {
	background: var(--sapButton_Lite_Background);
	border-color: fade(@sapUiButtonLiteTextColor, 50);
}

.sapMSubHeader-CTX .sapMBtnInner {
	background: var(--sapButton_Lite_Background);
}

.sapMBar-CTX :not(.sapMBtnDisabled) > .sapMBtnInner.sapMBtnActive,
.sapMBar-CTX :not(.sapMBtnDisabled) > .sapMBtnInner.sapMBtnTransparent.sapMBtnHoverable.sapMBtnActive,
.sapMBar-CTX :not(.sapMBtnDisabled) > .sapMBtnInner.sapMBtnGhost.sapMBtnHoverable.sapMBtnActive {
	background-color: var(--sapButton_Active_Background);
}

.sapMBtn:hover > .sapMBtnTransparent.sapMBtnHoverable:not(.sapMBtnActive):not(.sapMToggleBtnPressed),
.sapMIBar-CTX .sapMBtn:hover > .sapMBtnTransparent.sapMBtnHoverable:not(.sapMBtnActive):not(.sapMToggleBtnPressed) {
	background-color: var(--sapButton_Lite_Hover_Background);
	border-color: var(--sapButton_Lite_Hover_BorderColor);
	color: var(--sapButton_Lite_Hover_TextColor);

	bdi {
		color: var(--sapButton_Lite_Hover_TextColor);
	}
}

.sapMIBar-CTX .sapMBtn:hover > .sapMBtnGhost.sapMBtnHoverable:not(.sapMBtnActive):not(.sapMToggleBtnPressed) {
	background: var(--sapButton_Hover_Background);
	border-color: var(--sapButton_Hover_BorderColor);
}


.sapMIBar-CTX .sapMBtn:hover > .sapMBtnHoverable:not(.sapMBtnActive) {
	border-color: transparent;
}

.sapMIBar-CTX .sapMBtn:hover > .sapMBtnHoverable.sapMBtnAccept:not(.sapMBtnActive) {
	background-color: var(--sapButton_Accept_Hover_Background);
	border-color: var(--sapButton_Accept_Hover_BorderColor);
	color: var(--sapButton_Accept_TextColor);
}

.sapMIBar-CTX .sapMBtn:hover > .sapMBtnHoverable.sapMBtnAttention:not(.sapMBtnActive) {
	background-color: var(--sapButton_Attention_Hover_Background);
	border-color: var(--sapButton_Attention_Hover_BorderColor);
	color: var(--sapButton_Attention_Hover_TextColor);
}

.sapMIBar-CTX .sapMBtn:hover > .sapMBtnHoverable.sapMBtnReject:not(.sapMBtnActive) {
	background-color: var(--sapButton_Reject_Hover_Background);
	border-color: var(--sapButton_Reject_Hover_BorderColor);
	color: var(--sapButton_Reject_TextColor);
}

.sapMIBar-CTX .sapMBtn:hover > .sapMBtnHoverable.sapMBtnEmphasized:not(.sapMBtnActive) {
	background-color: var(--sapButton_Emphasized_Hover_Background);
	border-color: var(--sapButton_Emphasized_Hover_BorderColor);
	color: var(--sapButton_Emphasized_TextColor);
	text-shadow: 0 0 0.125rem var(--sapButton_Emphasized_TextShadow);
}

.sapMIBar-CTX .sapMBtn:hover > .sapMBtnHoverable.sapMBtnCritical:not(.sapMBtnActive) {
	background-color: darken(@sapUiCriticalElement, 7);
	border-color: darken(@sapUiCriticalElement, 7);
}

.sapMIBar-CTX .sapMBtn:hover > .sapMBtnHoverable.sapMBtnNegative:not(.sapMBtnActive) {
	background-color: darken(@sapUiNegativeElement, 7);
	border-color: darken(@sapUiNegativeElement, 7);
}

.sapMIBar-CTX .sapMBtn:hover > .sapMBtnHoverable.sapMBtnSuccess:not(.sapMBtnActive) {
	background-color: darken(@sapUiPositiveElement, 7);
	border-color: darken(@sapUiPositiveElement, 7);
}

.sapMIBar-CTX .sapMBtn:hover > .sapMBtnHoverable.sapMBtnNeutral:not(.sapMBtnActive) {
	background-color: var(--sapButton_Neutral_Hover_Background);
	border-color: var(--sapButton_Neutral_Hover_BorderColor);
}

.sapMIBar-CTX .sapMBtn:hover > .sapMBtnHoverable.sapMBtnCritical.sapMBtnActive {
	background-color: darken(@sapUiCriticalElement, 10);
	border-color: darken(@sapUiCriticalElement, 10);
}

.sapMIBar-CTX .sapMBtn:hover > .sapMBtnHoverable.sapMBtnNegative.sapMBtnActive {
	background-color: darken(@sapUiNegativeElement, 10);
	border-color: darken(@sapUiNegativeElement, 10);
}

.sapMIBar-CTX .sapMBtn:hover > .sapMBtnHoverable.sapMBtnSuccess.sapMBtnActive {
	background-color: darken(@sapUiPositiveElement, 10);
	border-color: darken(@sapUiPositiveElement, 10);
}

.sapMIBar-CTX .sapMBtn:hover > .sapMBtnHoverable.sapMBtnNeutral.sapMBtnActive {
	background-color: var(--sapButton_Neutral_Active_Background);
	border-color: var(--sapButton_Neutral_Active_BorderColor);
}

/* Separators between buttons in a footer */
.sapMFooter-CTX .sapMBtnInner :not(.sapMBtnDisabled),
html.sap-desktop .sapMFooter-CTX .sapMBtnInner :not(.sapMBtnDisabled) {
	border-color: var(--sapButton_Lite_BorderColor);
}

.sapMIBar-CTX .sapMBtnTransparent:not(.sapMBtnDisabled):not(.sapMToggleBtnPressed) {
	text-shadow: none;
	border-color: var(--sapButton_Lite_BorderColor);
}

/* active transparent button in a footer */
.sapMIBar-CTX.sapMFooter-CTX :not(.sapMBtnDisabled) {

	.sapMBtnTransparent.sapMBtnActive {
		background-color: var(--sapButton_Lite_Active_Background);
		color: var(--sapButton_Active_TextColor);
		border-color: var(--sapButton_Lite_Active_BorderColor);
	}
}

.sapMIBar-CTX .sapMBtnDisabled,
.sapMIBar-CTX .sapMBtnDisabled .sapMBtnContent > .sapMBtnIcon {
	color: @sapUiButtonHeaderDisabledTextColor;
	text-shadow: none;
}

.sapMIBar-CTX.sapMHeader-CTX :not(.sapMBtnDisabled) > .sapMBtnActive,
.sapMIBar-CTX.sapMFooter-CTX :not(.sapMBtnDisabled) > .sapMBtnActive {
	background-color: var(--sapButton_Active_Background);
	color: var(--sapButton_Active_TextColor);
	text-shadow: none;
}

.sapUiSizeCompact .sapMBar-CTX .sapMBtnInner.sapMBtnGhost:not(.sapMBtnDisabled) {
	background: var(--sapButton_Lite_Background);
	border: 0.0625rem solid var(--sapButton_BorderColor);
}

html.sap-desktop .sapMFooter-CTX .sapMBtnInner.sapMBtnAccept {
	border-color: var(--sapButton_Accept_BorderColor);
}

html.sap-desktop .sapMFooter-CTX .sapMBtnInner.sapMBtnAttention {
	border-color: var(--sapButton_Attention_BorderColor);
}

html.sap-desktop .sapMFooter-CTX .sapMBtnInner.sapMBtnReject {
	border-color: var(--sapButton_Reject_BorderColor);
}

.sapMBar-CTX,
.sapMTB-Transparent-CTX {

	& :not(.sapMBtnDisabled) > span.sapMBtnInner.sapMBtnTransparent.sapMBtnActive {

		& > .sapMBtnContent,
		& > .sapMBtnIcon {
			color: var(--sapButton_Active_TextColor);
		}
	}
}

.sap-desktop .sapMIBar-CTX, .sap-desktop .sapMTB-Transparent-CTX {

	.sapMBtn:not(.sapMBtnDisabled):hover > .sapMBtnInner:not(.sapMToggleBtnPressed):not(.sapMBtnEmphasized):not(.sapMBtnAccept):not(.sapMBtnAttention):not(.sapMBtnReject):not(.sapMBtnActive):not(.sapMBtnGhost):not(.sapMBtnCritical):not(.sapMBtnNegative):not(.sapMBtnNeutral):not(.sapMBtnSuccess) {
		border-color: var(--sapButton_Hover_BorderColor);
	}
}

.sapMTB-Transparent-CTX .sapMBtn:not(.sapMBtnDisabled) > .sapMBtnDefault.sapMBtnActive {
	background-color: var(--sapButton_Active_Background);
}

:not(.sapMBtnDisabled) > span.sapMBtnInner.sapMBtnIconFirst.sapMBtnTransparent.sapMBtnActive,
:not(.sapMBtnDisabled) > span.sapMBtnInner.sapMBtnIconLast.sapMBtnTransparent.sapMBtnActive {
	background-color: var(--sapButton_Lite_Active_Background);
	border-color: var(--sapButton_Lite_Active_BorderColor);
}
/* END "Button.less" */

/* START "Carousel.less" */
/* =============================== */
/* CSS for control sap.m/Carousel  */
/* Fiori 3 theme                   */
/* =============================== */

/* ========================================================================== */
/* Variables overriding */
/* ========================================================================== */

@_sap_m_Carousel_BackgroundColorSolid: var(--sapGroup_ContentBackground);
@_sap_m_Carousel_BackgroundColorTranslucent: var(--sapBackgroundColor);
@_sap_m_Carousel_MinWidth: 15.5rem;
@_sap_m_Carousel_ControlsNoArrowsHeight: 2.75rem;
@_sap_m_Carousel_NumericIndicatorTextColor: var(--sapPageFooter_TextColor);
@_sap_m_Carousel_PrevAndNextSize: 2.125rem;
@_sap_m_Carousel_PrevAndNextPosition: 0.5rem;
@_sap_m_Carousel_PageIndicatorWidthSizeS: 9rem;
@_sap_m_Carousel_PageIndicatorWidthSizeM: @_sap_m_Carousel_PageIndicatorWidthSizeS;
@_sap_m_Carousel_PageIndicatorWidthSizeL: @_sap_m_Carousel_PageIndicatorWidthSizeS;
@_sap_m_Carousel_PageIndicatorWidthSizeXL: @_sap_m_Carousel_PageIndicatorWidthSizeS;
@_sap_m_Carousel_PageIndicatorContainerPadding: 0.5rem;
/* END "Carousel.less" */

/* START "CheckBox.less" */
/* =============================== */
/* CSS for control sap.m/CheckBox  */
/* Fiori 3 theme                   */
/* =============================== */

.sapMCb {
	height: 2.75rem;
	line-height: 2.75rem;
	padding: 0 0 0 2.75rem;
}

.sapMCbBg {
	left: 0.6875rem;
	top: 0.6875rem;
	height: 1.375rem;
	width: 1.375rem;
	line-height: 1.125rem;
	border-width: 0.0625rem;
	box-sizing: border-box;

	&:not(.sapMCbErr):not(.sapMCbInfo):not(.sapMCbWarn) > & {
		line-height: 1.25rem;
	}
}

.sapMCb.sapMCbWarn .sapMCbBg {
	background-color: var(--sapField_WarningBackground);
	border: 0.125rem solid var(--sapField_WarningColor);

	&.sapMCbMarkChecked::before {
		color: var(--sapField_TextColor);
	}
}

.sapMCb.sapMCbSucc .sapMCbBg {
	background-color: var(--sapField_SuccessBackground);
	border: 0.0625rem solid var(--sapField_SuccessColor);

	&.sapMCbMarkChecked::before {
		color: var(--sapField_SuccessColor);
	}
}

.sapMCb.sapMCbErr .sapMCbBg {
	background-color: var(--sapField_InvalidBackground);
	border: 0.125rem solid var(--sapField_InvalidColor);

	&.sapMCbMarkChecked::before {
		color: var(--sapField_InvalidColor);
	}
}

.sapMCb.sapMCbInfo .sapMCbBg {
	background-color: var(--sapField_InformationBackground);
	border: 0.125rem solid var(--sapField_InformationColor);

	&.sapMCbMarkChecked::before {
		color: var(--sapField_InformationColor);
	}
}

.sapMCbBg.sapMCbMarkChecked::before {
	color: var(--sapSelectedColor);
}

.sapMCbBg.sapMCbMarkChecked.sapMCbMarkPartiallyChecked::before {
	border: 0.25rem solid transparent;
}

/* CheckBox focus */
.sapMCb:focus {
	outline: none;
}

/* In Form Checkbox needs to be left aligned to bi in line with other controls (as Form itself has a padding) */
.sapUiForm {

	.sapMCbBg {
		left: 0;
	}

	.sapMCb {
		padding-left: 2.0625rem; /* to have right gap between checkbox and label */
	}
}

html.sap-desktop {

	.sapMCbBg:focus,
	.sapMCbBg:active,
	.sap-desktop .sapMCbBg.sapMCbBgDis:focus {
		-webkit-tap-highlight-color: rgba(255, 255, 255, 0);
		outline: none;
	}

	.sapMCb:not(.sapMCbBgDis):not(.sapMCbHasLabel):focus > .sapMCbBg {
		outline-width: 1px;
		outline-style: dotted;
		outline-color: var(--sapContent_FocusColor);
		outline-offset: 0.0625rem;
	}

	.sapMCb:not(.sapMCbBgDis):not(.sapMCbDisplayOnly).sapMCbHasLabel {

		&:focus::before {
			content: '';
			display: block;
			position: absolute;
			top: 0.5625rem;
			bottom: 0.5625rem;
			left: 0.5625rem;
			right: -0.0625rem;
			border: 1px dotted var(--sapContent_FocusColor);
		}

		&:not(.sapMCbErr):not(.sapMCbInfo):not(.sapMCbWarn):focus::before {
			bottom: 0.5625rem;
		}
	}

	.sapUiForm .sapMCb:not(.sapMCbBgDis).sapMCbHasLabel:focus::before {
		left: -0.125rem;
	}
}

/* CheckBox in Footer Context */
.sapMFooter-CTX .sapMCb:not(.sapMCbBgDis):focus > .sapMCbBg,
.sapMFooter-CTX .sapMCb:not(.sapMCbBgDis) > .sapMCbBg:focus {
	outline-color: var(--sapContent_ContrastFocusColor);
}

.sapMLIBActive .sapMCbBg,
.sapMLIBActive .sapMCbBg.sapMCbMarkChecked,
.sapMLIBActive .sapMCbBg.sapMCbBgDis,
.sapMLIBActive .sapMCbBg.sapMCbBgDis.sapMCbMarkChecked {
	border-color: var(--sapList_Active_TextColor);
}

.sapMLIBActive .sapMCbBg {
	background-color: var(--sapList_Active_Background);
}

.sapMCbHoverable:hover {
	border-color: var(--sapField_Hover_BorderColor);
	background: var(--sapField_Hover_Background);
}

.sapMCbBgDis {
	opacity: var(--sapContent_DisabledOpacity);
}

.sapMLIBActive .sapMActive .sapMCbBg.sapMCbActiveStateOff.sapMCbMarkChecked::before,
.sapMLIBActive .sapMCbBg:active.sapMCbActiveStateOff.sapMCbMarkChecked::before,
.sapMLIBActive .sapMCbBg.sapMCbMarkChecked::before,
.sapMLIBActive .sapMActive .sapMCbBg.sapMCbMarkChecked::before,
.sapMLIBActive .sapMCbBg:active.sapMCbMarkChecked::before,
.sapMLIBActive .sapMCbBg.sapMCbBgDis.sapMCbMarkChecked::before {
	color: var(--sapList_Active_TextColor);
}

.sapMCbBg.sapMCbBgDis.sapMCbMarkChecked::before {
	color: fade(@sapUiSelected, 25);
}

/* Compact size */
.sapUiSizeCompact {

	.sapMCbBg {
		border-radius: 0.125rem;
	}

	/* In Form Checkbox needs to be left aligned to bi in line with other controls (as Form itself has a padding) */
	.sapUiForm {

		.sapMCbBg {
			left: 0;
		}

		.sapMCb {
			padding-left: 1.5rem; /* to have right gap between checkbox and label */
		}
	}
}

html.sap-desktop {

	.sapUiSizeCompact {

		.sapMCb:not(.sapMCbBgDis).sapMCbHasLabel {

			&:focus::before {
				top: 0.365rem;
				bottom: 0.365rem;
				left: 0.365rem;
			}

			&:not(.sapMCbErr):not(.sapMCbInfo):not(.sapMCbWarn):focus::before {
				bottom: 0.375rem;
			}
		}

		.sapMCbBg.sapMCbMarkChecked.sapMCbMarkPartiallyChecked::before {
			border-width: 0.1875rem;
		}

		.sapUiForm .sapMCb:not(.sapMCbBgDis):focus::before {
			left: -0.125rem;
		}

		.sapMCbBg {
			height: 1rem;
			width: 1rem;
			box-sizing: border-box;
		}

		.sapMCb:not(.sapMCbErr):not(.sapMCbInfo):not(.sapMCbWarn) > .sapMCbBg {
			line-height: 0.875rem;
		}
	}
}

/* END "CheckBox.less" */

/* START "ColorPalette.less" */
/* =================================== */
/* CSS for control sap.m/ColorPalette  */
/* Fiori 3 theme                       */
/* =================================== */

.sapMColorPalette .sapMColorPaletteSquare:hover > div,
.sapMColorPalette .sapMColorPaletteSquare.sapMColorPaletteSquareSelected > div,
.sapMColorPalette .sapMColorPaletteSquare,
html:not(.sap-phone) .sapMColorPalette .sapMColorPaletteSquare:hover > div,
html:not(.sap-phone) .sapMColorPalette .sapMColorPaletteSquare.sapMColorPaletteSquareSelected > div,
html:not(.sap-phone) .sapMColorPalette .sapMColorPaletteSquare {
	border-radius: 0.25rem;
}

html:not(.sap-phone) .sapMColorPalette .sapMColorPaletteSquare div,
.sapMColorPalette .sapMColorPaletteSquare div {
	border-radius: 0.125rem;
}

.sap-desktop .sapMColorPalette .sapMBtn:focus {

	&::after {
		border-color: var(--sapContent_FocusColor);
	}

	&:active::after {
		border-color: var(--sapContent_ContrastFocusColor);
	}
}

.sap-desktop .sapContrast,
.sap-desktop.sapContrast {

	.sapMColorPalette .sapMBtn {

		&:focus::after {
			border-color: var(--sapContent_FocusColor);
		}

		&:active,
		> .sapMBtnActive,
		&:hover > .sapMBtnActive,
		&:active > .sapMBtnActive {
			color: var(--sapList_TextColor);
		}
	}
}
/* END "ColorPalette.less" */

/* START "CustomTile.less" */
/* ========================= */
/* CSS for sap.m/CustomTile  */
/* Fiori 3 theme             */
/* ========================= */

.sapMCustomTile:focus {
	outline: 1px dotted var(--sapContent_FocusColor);
}
/* END "CustomTile.less" */

/* START "Dialog.less" */
/* ============================= */
/* CSS for control sap.m/Dialog  */
/* Fiori 3 theme                 */
/* ============================= */

/* ========================================================================== */
/* Variables */
/* ========================================================================== */

@_sap_m_Dialog_VerticalMargin: 3%;
@_sap_m_Dialog_BarHeight: 2.75rem;
@_sap_m_Dialog_SubHeaderCompactHeight: 2.25rem;

@_sap_m_Dialog_NoStateHeaderShadow: @sapUiShadowHeader;
@_sap_m_Dialog_SuccessHeaderShadow: inset 0 -0.0625rem var(--sapSuccessBorderColor), @sapUiShadowHeader;
@_sap_m_Dialog_ErrorHeaderShadow: inset 0 -0.0625rem var(--sapErrorBorderColor), @sapUiShadowHeader;
@_sap_m_Dialog_WarningHeaderShadow: inset 0 -0.0625rem var(--sapWarningBorderColor), @sapUiShadowHeader;
@_sap_m_Dialog_InformationHeaderShadow: inset 0 -0.0625rem var(--sapInformationBorderColor), @sapUiShadowHeader;

/* This parameter is used in sap.m.Select. TODO: remove it when it is removed from there. */
@_sap_m_Dialog_HeaderShadowColor: darken(@sapUiGroupContentBackground, 8);

.sapMDialogSubHeader .sapMIBar {
	height: 100%;
	padding-bottom: 0.25rem;
	box-sizing: border-box;
}

.sapMDialog > header .sapMDialogTitleGroup .sapMDialogIcon.sapUiIcon {
	font-size: 1rem;
}

.sapMDialogBeginButton, .sapMDialogEndButton {
	min-width: 4rem;
}

.sapMDialogTitleGroup {
	z-index: 3; /* to hide the shadow from the header when there is sub-header */
}

/* buttons on phone must be to the right side (in LTR mode) */
html.sap-phone .sapMDialog {

	& > footer .sapMFooter-CTX {
		justify-content: flex-end;
	}
}

/* ========================================================================== */
/* header, sub-header, footer */
/* ========================================================================== */

.sapMDialog {

	header .sapMBarLeft,
	header .sapMBarPH {
		padding-left: 1rem;
	}

	header .sapMBarRight,
	header .sapMBarPH {
		padding-right: 1rem;
	}

	header .sapMTB,
	footer .sapMTB {
		padding: 0 1rem;
	}
}

.sapMDialogTitleGroup,
.sapMDialogSubHeader {

	.sapUi-Std-PaddingS,
	.sapUi-Std-PaddingM,
	.sapUi-Std-PaddingL,
	.sapUi-Std-PaddingXL {

		&.sapMIBar {

			.sapMBarMiddle .sapMBarPH {
				padding-left: 0;
				padding-right: 0;
			}

			.sapMBarLeft {
				padding-left: inherit;

				.sapMBarChild {
					padding-right: 0.5rem;
				}
			}

			.sapMBarRight {
				padding-right: inherit;

				.sapMBarChild {
					padding-left: 0.5rem;
				}
			}
		}
	}
}
/* END "Dialog.less" */

/* START "DraftIndicator.less" */
/* ===================================== */
/* CSS for control sap.m/DraftIndicator  */
/* Fiori 3 theme                         */
/* ===================================== */

.sapMDraftIndicator .sapMLabel {
	vertical-align: middle;
	line-height: 2rem;
	padding: 0 0.5rem 0 0.5rem;
}
/* END "DraftIndicator.less" */

/* START "MessagePage.less" */
/* ================================== */
/* CSS for control sap.m/MessagePage  */
/* Fiori 3 theme                      */
/* ================================== */

/* MessagePage inner controls styles */
.sapMMessagePage {

	.sapMMessagePageInner {

		.sapMMessagePageIcon.sapUiIcon::before {
			color: fade(@sapUiContentNonInteractiveIconColor,50);
		}
	}

	.sapMMessagePageMainText {
		margin: 1rem 0;
	}

	.sapMMessagePageDescription {
		margin-top: 0;
		margin-bottom: 2rem;

		&:empty {
			margin-bottom: 0;
		}

		.sapMLnk {
			font-size: var(--sapFontHeader5Size);
		}
	}

	.sapMMessagePageButtonsWrapper {
		margin: 0;
	}
}
/* END "MessagePage.less" */

/* START "GenericTag.less" */
/* ================================= */
/* CSS for control sap.m/GenericTag  */
/* Fiori 3 theme                     */
/* ================================= */

@_sap_m_GenericTag_BorderWidth: 0.375rem;
@_sap_m_GenericTag_IconPaddingRight: 0.375rem;
@_sap_m_GenericTag_PaddingLeft: 0.375rem;

.sapMGenericTag {

	.sapMGenericTagWrap {
		padding: 0 0 0 @_sap_m_GenericTag_PaddingLeft;
		border-radius: var(--sapButton_BorderCornerRadius);
		border-left-width: @_sap_m_GenericTag_BorderWidth;

		.sapMGenericTagText {
			margin-right: 0.375rem;
		}

		.sapMGenericTagValue {
			margin-left: 0.75rem;
			margin-right: 0.375rem;
			padding-left: 0;
		}

		.sapMGenericTagErrorIcon {
			margin-right: 0.375rem;
		}
	}
}

.sapMGenericTagWrap {

	.sapMGenericTagError & {
		border-color: var(--sapNegativeElementColor);

		.sapMGenericTagIcon {
			color: var(--sapNegativeElementColor);
		}
	}

	.sapMGenericTagWarning & {
		border-color: var(--sapCriticalElementColor);

		.sapMGenericTagIcon {
			color: var(--sapCriticalElementColor);
		}
	}

	.sapMGenericTagSuccess & {
		border-color: var(--sapPositiveElementColor);

		.sapMGenericTagIcon {
			color: var(--sapPositiveElementColor);
		}
	}

	.sapMGenericTagInformation & {
		border-color: var(--sapInformativeElementColor);

		.sapMGenericTagIcon {
			color: var(--sapInformativeElementColor);
		}
	}

	.sapMGenericTagNone & {
		border-color: var(--sapNeutralElementColor);

		.sapMGenericTagIcon {
			color: var(--sapNeutralElementColor);
		}
	}

	&:hover {
		background: var(--sapList_Hover_Background);
	}

	.sapMGenericTagActive & {
		background: var(--sapList_Active_Background);

		.sapMGenericTagIcon {
			color: var(--sapList_Active_TextColor);
		}
	}
}

html.sap-desktop .sapMGenericTag {

	&::before {
		border: 1px solid var(--sapContent_FocusColor);
	}

	&::after {
		border: 1px dotted var(--sapContent_ContrastFocusColor);
	}
}

.sapUiSizeCozy {

	.sapMGenericTag {
		margin: 0.5625rem 0;

		.sapMGenericTagWrap {
			height: 1.625rem;
		}
	}
}

html.sap-phone .sapMGenericTag {
	margin-top: 0.5625rem;
	margin-bottom: 0.5625rem;
}
/* END "GenericTag.less" */

/* START "GenericTile.less" */
/* ================================== */
/* CSS for control sap.m/GenericTile  */
/* Fiori 3 theme                      */
/* ================================== */

.sapMGT.sapMGTBackgroundImage {

	.sapMGTContent {
		border-bottom-left-radius: 0.125rem;
		border-bottom-right-radius: 0.125rem;
		height: auto;
	}
}

.sapMGT.sapMGTScopeActions.sapMGTBackgroundImage .sapMGTMoreIcon {
	color: var(--sapContent_ContrastTextColor);
}

/* LINE MODE LIST VIEW */

.sapMGT.sapMGTLineMode {
	transition: background 0.2s;
	background: transparent;
}

.sapMGT.sapMGTLineMode:not(.sapMGTDisabled) {

	&:not(.sapMGTLineModePress):hover {
		background: var(--sapTile_Hover_Background);
	}
}

.sapMGT.sapMGTLineMode:not(.sapMGTDisabled).sapMGTLineModePress {
	background: var(--sapTile_Background);
}

.sapMGT.sapMGTLineMode .sapMGTFocusDiv {
	border-radius: 0;
}

.sapMGTLineMode .sapMGTLineModeFailedIcon {
	cursor: pointer;
	color: var(--sapContent_NonInteractiveIconColor);
	text-shadow: @sapUiShadowText;
}

.sapMGTLineMode.sapMGTDisabled > .sapMGTTouchArea > *:not(.sapMGTActionsContainer) {
	opacity: 0.5;
}

.sapMGTLineMode.sapMGTFailed .sapMGTLineModeFailedIcon ~ *:not(.sapMGTStyleHelper):not(.sapMGTActionsContainer):not(.sapMGTEndMarker) {
	opacity: 0.5;
}

.sapMGTLineMode .sapMGTActionsContainer .sapMGTRemoveButton {
	background-color: var(--sapButton_Background);
	color: var(--sapButton_TextColor);

	&::before {
		color: var(--sapButton_IconColor);
	}
}

.sapMGTLineMode .sapMGTLineModeHelpContainer:not(:last-child) {
	-webkit-mask-image: linear-gradient(to right, #FFF ~"calc(100% - 1.5rem)", transparent);

	html[dir~=rtl] & {
		-webkit-mask-image: linear-gradient(to left, #FFF ~"calc(100% - 1.5rem)", transparent);
	}

	.sapMGTHdrTxt,
	.sapMGTSubHdrTxt {
		text-overflow: clip;
	}
}

/* LINE MODE FLOATING VIEW */

.sapUiMedia-GenericTileDeviceSet-large {

	.sapMGT.sapMGTLineMode:not(.sapMGTDisabled) {

		&:focus,
		&.sapMGTLineModePress {

			.sapMGTLineStyleHelperInner::before {
				content: '';
				position: absolute;
				top: 1px;
				left: 1px;
				bottom: 1px;
				right: 1px;
				box-sizing: border-box;
				border: 1px dotted var(--sapContent_FocusColor);
			}
		}
	}
}

.sapUiMedia-GenericTileDeviceSet-large {

	.sapMGT.sapMGTLineMode:not(.sapMGTDisabled) {

		&:hover .sapMGTLineStyleHelperInner {
			background: var(--sapTile_Hover_Background);
		}
	}

	.sapMGT.sapMGTLineMode {
		font-size: @sapMFontMediumSize;

		& * {
			font-size: @sapMFontMediumSize;
		}

		&.sapMGTDisabled {

			.sapMGTHdrTxt,
			.sapMGTSubHdrTxt {
				opacity: 0.5;
			}
		}

		.sapMGTLineStyleHelper {

			&:first-child:not(:only-child) .sapMGTLineStyleHelperInner {
				margin-right: 0.125rem;
			}

			&:not(:first-child) .sapMGTLineStyleHelperInner {
				margin: 0 0.125rem;
			}

			&:last-child .sapMGTLineStyleHelperInner {
				margin-right: 0;
			}

			&:first-child .sapMGTLineStyleHelperInner {
				border-top-left-radius: 0.2rem;
				border-bottom-left-radius: 0.2rem;
			}

			&:last-child .sapMGTLineStyleHelperInner {
				border-top-right-radius: 0.2rem;
				border-bottom-right-radius: 0.2rem;
			}
		}

		.sapMGTLineStyleHelperInner {
			transition: background 0.2s;
		}

		&.sapMGTLineModePress:not(.sapMGTDisabled) {

			&,
			&:hover {

				.sapMGTLineStyleHelperInner {
					background: var(--sapTile_Active_Background);
				}
			}
		}
	}
}

.sapMGTLineMode .sapMGTHdrTxt {
	color: var(--sapLinkColor);
	font-size: @sapMFontMediumSize;
	text-shadow: @sapUiShadowText;
}

.sapMGTLineMode .sapMGTSubHdrTxt {
	color: var(--sapTile_TextColor);
	font-size: @sapMFontMediumSize;
	text-shadow: @sapUiShadowText;
}

.sapMGTWithoutImageHoverOverlay,
.sapMGTWithImageHoverOverlay {
	z-index: 1;
	position: absolute;
	pointer-events: none;
	top: 0;
	right: 0;
	left: 0;
	bottom: 0;
	border-radius: 0.25rem
}

html.sap-phone .sapMGTWithoutImageHoverOverlay,
html.sap-phone .sapMGTWithImageHoverOverlay,
html.sap-tablet .sapMGTWithoutImageHoverOverlay,
html.sap-tablet .sapMGTWithImageHoverOverlay {
	position: absolute;
	pointer-events: none;
	top: 0;
	right: 0;
	left: 0;
	bottom: 0;
	border-radius: 0.25rem
}

.sapMGT.sapMGTPressActive {
	box-shadow: none;

	&:not(.sapMGTBackgroundImage) {
		background: var(--sapTile_Active_Background);
	}

	&.sapMGTScopeActions .sapMTileCntContent::after {
		background-color: var(--sapTile_Active_Background);
		// opacity: 0.7;
	}
}

.sapMGT:hover:not(.sapMGTPressActive) {
	box-shadow: none;
	outline: 1px solid var(--sapTile_Interactive_BorderColor);
	background-color: var(--sapTile_Hover_Background);

	&.sapMGTBackgroundImage {
		background-color: var(--sapTile_Hover_Background);
		opacity: 0.9;
	}

	&.sapMGTScopeActions .sapMTileCntContent::after {
		background-color: var(--sapTile_Hover_Background);
	}
}

.sapMGTActionButtonPress.sapMGT:active {

	.sapMGTFocusDiv {
		border: none;
	}
}

.sapMGTActionButtonPress.sapMGT:focus-visible {

	.sapMGTFocusDiv {
		border: var(--sapContent_FocusColor) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);
	}
}

.sapMGT.sapMGTBackgroundImage:focus .sapMGTFocusDiv,
.sapMGT.sapMGTBackgroundImage:active .sapMGTFocusDiv {

	&::after {
		content: '';
		.sapMGTOverlayMixin();
		border-radius: 0.25rem;
		border: var(--sapContent_FocusColor) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);
		z-index: 0;
	}
}
/* END "GenericTile.less" */

/* START "GroupHeaderListItem.less" */
/* ========================================= */
/* CSS for control sap.m/GroupHeaderListItem */
/* Fiori 3 theme                             */
/* ========================================= */

.sapMListUl .sapMLIB.sapMGHLI {
	font-weight: bold;
}
/* END "GroupHeaderListItem.less" */

/* START "FeedInput.less" */
/* ================================ */
/* CSS for control sap.m/FeedInput  */
/* Fiori 3 theme                    */
/* ================================ */

@_sap_m_FeedInput_BackgroundColor: darken(@sapUiBaseColor, 9);

.sapMFeedIn {
	background-color: var(--sapGroup_ContentBackground);
}

.sapMFeedIn.sapMFeedInDisabled {
	opacity: var(--sapContent_DisabledOpacity);
}

.sapMFeedIn .sapMInputBase .sapMTextArea .sapMTextAreaInner {
	min-width: 6rem;
	margin-top: 0.25rem;
}

.sapMFeedInImage {
	font-size: 1.25rem;
}

.sapMFeedIn .sapMInputBase .sapMTextArea {
	background-color: var(--sapField_Background);
	padding: 0;
}

.sapMFeedIn > .sapMFeedInContainer > .sapMTextArea > .sapMInputBaseInner {
	color: var(--sapField_TextColor);
}

.sapMFeedIn .sapMBtn {
	width: 4.0rem;
	height: 3.75rem;
	padding: 0.25rem 0.625rem 0.25rem 0.625rem;
	margin: 0.125rem 0 0.125rem 0.5rem;
	position: absolute;
	right: 0;
	bottom: 0;
	border-width: var(--sapButton_BorderWidth);
	border-radius: var(--sapButton_BorderCornerRadius);
	background-color: var(--sapGroup_ContentBackground);
	font-size: @sapFontSize;
	font-family: var(--sapFontSemiboldDuplexFamily);
}

.sapMFeedIn .sapMBtnInner {
	padding: 0;
	border-radius: var(--sapButton_BorderCornerRadius);
	background-color: var(--sapButton_Background);
	border: 1px solid var(--sapButton_BorderColor);
	color: var(--sapButton_TextColor);
}

.sapMFeedIn .sapMBtnIcon {
	width: 2.25rem;
	height: 2.25rem;
	margin: 0.125rem 0 0.125rem 0;
	padding: 0 0.625rem 0 0.625rem;
	border-width: var(--sapButton_BorderWidth);
	border-radius: var(--sapButton_BorderCornerRadius);
}

.sapMFeedIn .sapMFeedInContainer {
	background-color: var(--sapGroup_ContentBackground);
}
/* END "FeedInput.less" */

/* START "HeaderContainer.less" */
/* ====================================== */
/* CSS for control sap.m/HeaderContainer  */
/* Fiori 3 theme                          */
/* ====================================== */

@_sap_m_HeaderContainer_TranslucentBackground: fade(@sapUiObjectHeaderBackground, 100);

.sapMHdrCntrBtn > .sapMBtnInner {
	border: none;
}

.sapMHdrCntrBGTransparent {
	background-color: transparent;
}

.sapMHdrCntrBGTranslucent {
	background-color: @_sap_m_HeaderContainer_TranslucentBackground;
}
/* END "HeaderContainer.less" */

/* START "IconTabBar.less" */
/* ================================= */
/* CSS for control sap.m/IconTabBar  */
/* Quartz Light theme                 */
/* ================================= */

/* ========================================================================== */
/* Variables overriding */
/* ========================================================================== */

@_sap_m_IconTabBar_TextColor: var(--sapContent_LabelColor);
@_sap_m_IconTabBar_TextShadow: none;
@_sap_m_IconTab_Bar_Separator_Line: var(--sapGroup_TitleBorderColor);

/* ==================== Cozy size ==================== */

/* Content arrow */
@_sap_m_IconTabBar_ContentArrowHeight: 0.875rem;

/* Inline mode */
@_sap_m_IconTabBar_InLineFilterMargin: 0.875rem 0 0 0;
@_sap_m_IconTabBar_InLineTextOnlyVerticalHeight: 2.75rem;
@_sap_m_IconTabBar_InLineTextOnlyContentArrowHeight: @_sap_m_IconTabBar_ContentArrowHeight;

/* TextOnly mode */
@_sap_m_IconTabBar_TextOnlyTabPadding: 0 0 0.125rem 0;
@_sap_m_IconTabBar_TextOnlyVerticalHeight: 3rem;

/* NoText mode */
@_sap_m_IconTabBar_NoTextFilterWidth: 3.125rem;
@_sap_m_IconTabBar_NoTextVerticalHeight: 3.75rem;

/* All tabs */
@_sap_m_IconTabBar_AllTabHeight: 2.875rem;
@_sap_m_IconTabBar_AllTabLineHeight: 2.875rem;
@_sap_m_IconTabBar_AllTabMarginBottom: 0.375rem;

/* Horizontal tabs */
@_sap_m_IconTabBar_HorizontalFilterHeight: 3.75rem;
@_sap_m_IconTabBar_HorizontalTabHeight: 2.75rem;
@_sap_m_IconTabBar_HorizontalWrapperHeight: 2.75rem;
@_sap_m_IconTabBar_HorizontalTabWidth: 3.125rem;
@_sap_m_IconTabBar_HorizontalCountTop: 0.375rem;
@_sap_m_IconTabBar_HorizontalTextPaddingTop: 0.375rem;
@_sap_m_IconTabBar_HorizontalTextPaddingLeft: 0.125rem;

/* Vertical tabs */
@_sap_m_IconTabBar_VerticalHeight: 4.625rem;
@_sap_m_IconTabBar_VerticalContentArrowHeight: 0.625rem;

/* Filter icon */
@_sap_m_IconTabBar_FilterIconHeight: 2.75rem;
@_sap_m_IconTabBar_FilterIconWidth: 2.75rem;

/* Filter text */
@_sap_m_IconTabBar_FilterTextLineHeight: 0.875rem;

/* Separator */
@_sap_m_IconTabBar_SeparatorHeight: 2rem;
@_sap_m_IconTabBar_SeparatorMargin: 0.75rem 0.25rem 0;
@_sap_m_IconTabBar_TextOnlySeparatorMargin: 0.375rem 0.25rem 0.375rem;
@_sap_m_IconTabBar_TextOnlySeparatorMarginCompact: @_sap_m_IconTabBar_TextOnlySeparatorMargin;
@_sap_m_IconTabBar_SeparatorIconHeight: 2.75rem;
@__sap_m_IconTabBar_SeparatorIconLineHeight: 2.75rem;

/* Left and Right arrows */
@_sap_m_IconTabBar_ArrowScrollPadding: 0.875rem 0.4rem;
@_sap_m_IconTabBar_SplitContainerArrowScrollPadding: 0.875rem 0.4rem;

/* Header */
@_sap_m_IconTabBar_HeaderBackgroundTranslucent: var(--sapObjectHeader_Background);

@_sap_m_IconTabBar_HeaderBorderBottom: none;
@_sap_m_IconTabBar_HeaderShadow: 0 0.25rem 0.25rem -0.25rem fade(@sapUiContentShadowColor, 15), inset 0 -0.0625rem 0 0 var(--sapObjectHeader_BorderColor);

/* Content */
@_sap_m_IconTabBar_ContentBackground: var(--sapBackgroundColor);
@_sap_m_IconTabBar_ContentBackgroundTranslucent: var(--sapGroup_ContentBackground);

/* ==================== Compact size ==================== */

/* Content arrow */
@_sap_m_IconTabBar_Compact_NoTextContentArrowHeight: 1rem;
@_sap_m_IconTabBar_Compact_ContentArrowHeight: 1rem;
@_sap_m_IconTabBar_Compact_NoTextContentArrowWidth: 2.375rem;

/* Inline mode (same as cozy) */
@_sap_m_IconTabBar_Compact_InLineVerticalTabHeight: @_sap_m_IconTabBar_InLineTextOnlyVerticalHeight;
@_sap_m_IconTabBar_Compact_InLineFilterTextMargin: @_sap_m_IconTabBar_InLineFilterMargin;
@_sap_m_IconTabBar_Compact_TextOnlyContentArrowHeight: @_sap_m_IconTabBar_VerticalContentArrowHeight;

/* TextOnly (same as cozy) */
@_sap_m_IconTabBar_Compact_TextOnlyVerticalHeight: @_sap_m_IconTabBar_TextOnlyVerticalHeight;
@_sap_m_IconTabBar_Compact_TextOnlyTabPadding: @_sap_m_IconTabBar_TextOnlyTabPadding;
@_sap_m_IconTabBar_Compact_TextOnlyHeadPadding: 0 0.925rem 0 0.1875rem;
@_sap_m_IconTabBar_Compact_TextOnlyTextLineHeight: 1rem;
@_sap_m_IconTabBar_Compact_TextOnlyTextPadding: 0;

/* NoText */
@_sap_m_IconTabBar_Compact_NoTextTabWidth: 2.375rem;
@_sap_m_IconTabBar_Compact_NoTextVerticalHeight: 3rem;

/* Horizontal */
@_sap_m_IconTabBar_Compact_HorizontalHeight: 3rem;
@_sap_m_IconTabBar_Compact_HorizontalContentArrowHeight: 1rem;

/* Vertical */
@_sap_m_IconTabBar_Compact_VerticalHeight: 3.875rem;

/* Filter text */
@_sap_m_IconTabBar_Compact_FilterTextPadding: 0.375rem 0 0;

/* Focus border */
@_sap_m_IconTabBar_Compact_HorizontalFocusBottom: 1rem;

/* =========== Phone =========== */

/* Content arrow */
@_sap_m_IconTabBar_Phone_ContentArrowHeight: 0.625rem;

@_sap_m_IconTabBar_Phone_TextOnlyContentArrowHeight: 0.5rem;
@_sap_m_IconTabBar_Phone_Compact_TextOnlyContentArrowHeight: 0.75rem;

/* ========================================================================== */
/* Variables */
/* ========================================================================== */

@_sap_m_IconTabBar_TextHoverColor: darken(@sapUiGroupTitleTextColor, 10);
@_sap_m_IconTabBar_SelectedTextColor: var(--sapSelectedColor);
@_sap_m_IconTabBar_SelectedTextHoverColor: darken(@sapUiSelected, 10);
@_sap_m_IconTabBar_ArrowScroll_AfterHeight: 1px;

/* =========== Shell =========== */
@_sap_m_IconTabBar_ShellHeaderShadow: var(--sapShell_Shadow);

/* Head Container */
.sapMITH {
	z-index: 1; /* shows the bottom shadow of the ITHeader over the content of the ITB */

	.sapMITBHead {
		padding-top: 0.875rem;
	}

	&.sapMITBNoText {

		.sapMITBHead {
			padding-top: 1rem;
		}
	}

	&.sapMITBTextOnly {

		.sapMITBHead {
			padding-top: 0.875rem;
		}
	}

	&.sapMITBInLine {

		.sapMITBHead {
			padding-top: 0;
		}
	}
}

/* Head Container - compact */

.sapUiSizeCompact.sapMITH {

	.sapMITBHead {
		padding-top: 0.875rem;
	}

	&.sapMITBTextOnly {

		.sapMITBHead {
			padding-top: 0.875rem;
		}
	}

	&.sapMITBInLine {

		.sapMITBHead {
			padding-top: 0;
		}
	}

	/* Bottom borders on the currently selected tab - compact */
	&.sapMITBTextOnly .sapMITBVertical.sapMITBFilter .sapMITBContentArrow {
		height: 0.875rem;
	}

	&.sapMITBInLine.sapMITBTextOnly .sapMITBVertical.sapMITBFilter .sapMITBContentArrow {
		height: 0.875rem;
	}

	/* Tabs - compact*/
	.sapMITBAll {

		.sapMITBTab {
			margin-bottom: 0.3rem;
			margin-top: 0.6rem;
		}

		.sapMITBContentArrow {
			height: 1rem;
		}
	}

	.sapMITBHorizontal {

		&.sapMITBFilter .sapMITBHorizontalWrapper .sapMITBText {
			padding-top: 4px;
		}

		&.sapMITBAll .sapMITBTab {
			margin-bottom: 0.125rem;
			margin-top: 0;
		}

		+ .sapMITBSepLine {
			margin-top: 0.125rem;
		}
	}
}

.sapMITBContentArrow {
	position: relative;

	/* creates border bottom with rounded top corners */
	&::after {
		content: '';
		position: absolute;
		bottom: 0;
		left: 0;
		right: 0;
		border-radius: 0.125rem 0.125rem 0 0;
	}
}

.sapMITBHorizontal.sapMITBFilter {
	margin-top: 0.125rem;

	+ .sapMITBSep {
		margin-top: 0.125rem;
	}
}

/* Content Container */

.sapMITBContent {
	border-bottom: 0.0625rem solid var(--sapObjectHeader_BorderColor);
}

/* Tab Filter Item */

.sapMITBTextOnly {

	.sapMITBFilterDefault:hover .sapMITBText {
		color: @_sap_m_IconTabBar_TextHoverColor;
	}

	.sapMITBFilterDefault.sapMITBSelected .sapMITBText {
		color: @_sap_m_IconTabBar_SelectedTextColor;
	}

	.sapMITBFilterDefault.sapMITBSelected:hover .sapMITBText {
		color: @_sap_m_IconTabBar_SelectedTextHoverColor;
	}

	.sapMITBFilterNeutral .sapMITBText {
		color: var(--sapNeutralTextColor);
	}

	.sapMITBFilterPositive .sapMITBText {
		color: var(--sapPositiveTextColor);
	}

	.sapMITBFilterPositive:hover .sapMITBText {
		color: darken(@sapUiPositiveText, 10);
	}

	.sapMITBFilterNegative .sapMITBText {
		color: var(--sapNegativeTextColor);
	}

	.sapMITBFilterNegative:hover .sapMITBText {
		color: darken(@sapUiNegativeText, 10);
	}

	.sapMITBFilterCritical .sapMITBText {
		color: var(--sapCriticalTextColor);
	}

	.sapMITBFilterCritical:hover .sapMITBText {
		color: darken(@sapUiCriticalText, 10);
	}
}

.sapMITBFilterIcon {
	border: 1px solid var(--sapHighlightColor);
}

.sapMITBFilterDefault {
	color: var(--sapHighlightColor);
	border-color: var(--sapHighlightColor);
}

.sapMITBFilterNeutral {
	color: var(--sapNeutralElementColor);
	border-color: var(--sapNeutralElementColor);
}

.sapMITBFilterPositive {
	color: var(--sapPositiveElementColor);
	border-color: var(--sapPositiveElementColor);
}

.sapMITBFilterNegative {
	color: var(--sapNegativeElementColor);
	border-color: var(--sapNegativeElementColor);
}

.sapMITBFilterCritical {
	color: var(--sapCriticalElementColor);
	border-color: var(--sapCriticalElementColor);
}

.sapMITBSelected {

	.sapMITBContentArrow::after {
		background: @_sap_m_IconTabBar_SelectedTextColor;
	}

	&.sapMITBFilterNeutral .sapMITBContentArrow::after {
		background: var(--sapNeutralElementColor);
	}

	&.sapMITBFilterPositive .sapMITBContentArrow::after {
		background: var(--sapPositiveElementColor);
	}

	&.sapMITBFilterNegative .sapMITBContentArrow::after {
		background: var(--sapNegativeElementColor);
	}

	&.sapMITBFilterCritical .sapMITBContentArrow::after {
		background: var(--sapCriticalElementColor);
	}

	.sapMITBFilterDefault {
		background: @_sap_m_IconTabBar_SelectedTextColor;
		color: var(--sapContent_ContrastIconColor);
	}

	.sapMITBFilterNeutral {
		background: var(--sapNeutralElementColor);
		color: var(--sapGroup_ContentBackground);
	}

	.sapMITBFilterPositive {
		background: var(--sapPositiveElementColor);
		color: var(--sapGroup_ContentBackground);
	}

	.sapMITBFilterNegative {
		background: var(--sapNegativeElementColor);
		color: var(--sapGroup_ContentBackground);
	}

	.sapMITBFilterCritical {
		background: var(--sapCriticalElementColor);
		color: var(--sapGroup_ContentBackground);
	}
}

/* Phone device */

.sapUiMedia-Std-Phone .sapMITH.sapUiSizeCompact {

	&.sapMITBInLine.sapMITBTextOnly {

		.sapMITBHead .sapMITBContentArrow {
			height: 0.875rem;
		}
	}

	&.sapMITBTextOnly {

		.sapMITBHead .sapMITBContentArrow {
			height: 0.75rem;
		}
	}
}

.sapMITH.sapMITBNoText .sapMITBHead {

	> .sapMITBSepLine {
		margin: 0.25rem 0.25rem 0 0;
	}
}

.sapMITH.sapUiSizeCompact {

	&.sapMITBNoText .sapMITBHead {

		> .sapMITBSepLine {
			margin: 0 0.125rem 0 0.125rem;
		}
	}

	.sapMITBSepLine {
		border: unset;
		border-right: 1px solid @_sap_m_IconTab_Bar_Separator_Line;
		margin: 0.625rem 0.125rem 0 0.125rem;
	}
}

.sapMITBAll {

	.sapMITBTab {
		margin-top: 0.4rem;
	}

	&.sapMITBHorizontal {

		.sapMITBTab {
			margin-top: 0;
		}

		+ .sapMITBSepLine {
			margin-top: 0.5rem;
		}
	}
}

.sapMITBSepLine {
	border: unset;
	border-right: 1px solid @_sap_m_IconTab_Bar_Separator_Line;
}

.sapUiMedia-Std-Phone {

	.sapMITBSepLine {
		margin: 0.75rem 0.25rem 0;
	}
}

/* Custom focus outline */
html.sap-desktop {

	.sapMITBItem:not(.sapUiDnDDragging):focus.sapMITBAll {

		&::after {
			top: 0.75rem;
			bottom: 1.75rem;
		}
	}

	.sapMITH.sapUiSizeCompact {

		.sapMITBItem:focus.sapMITBAll {

			&::after {
				bottom: 1.3rem;
				top: 0.125rem;
			}
		}
	}

	.sapMITH {

		.sapMITHStartOverflow,
		.sapMITHEndOverflow {

			.sapMITBItem {

				&:active::after {
					/* when overflow is pressed, make the focus white */
					border-color: @_sap_m_IconTabBar_Overflow_TextColorPressed;
				}
			}
		}
	}
}
/* END "IconTabBar.less" */

/* START "InputBase.less" */
/* ================================ */
/* CSS for control sap.m/InputBase  */
/* Fiori 3 theme                    */
/* ================================ */

/* ========================================================================== */
/* Variables overriding */
/* ========================================================================== */

@_sap_m_InputBase_InnerMinWidth: 2.75rem;
@_sap_m_InputBase_InnerPadding: 0 0.625rem;
@_sap_m_InputBase_DisabledOpacity: var(--sapContent_DisabledOpacity);
@_sap_m_InputBase_IconLineHeight: 2.125rem;
@_sap_m_InputBase_IconWidth: 2.125rem;
@_sap_m_InputBase_IconMinWidth: 2.125rem;

.sapMInputBaseContentWrapper {

	&.sapMInputBaseContentWrapperState {

		&.sapMInputBaseContentWrapperSuccess {
			border-width: var(--sapField_SuccessBorderWidth);
			border-style: var(--sapField_SuccessBorderStyle);
		}

		&.sapMInputBaseContentWrapperError {
			border-width: var(--sapField_InvalidBorderWidth);
			border-style: var(--sapField_InvalidBorderStyle);
		}

		&.sapMInputBaseContentWrapperWarning {
			border-width: var(--sapField_WarningBorderWidth);
			border-style: var(--sapField_WarningBorderStyle);
		}

		&.sapMInputBaseContentWrapperInformation {
			border-width: var(--sapField_InformationBorderWidth);
			border-style: var(--sapField_InformationBorderStyle);
		}
	}

	&.sapMInputBaseContentWrapperState:not(.sapMInputBaseContentWrapperSuccess) {
		/* calculated line-height excluding the top and bottom borders */
		.sapMInputBaseIcon {
			line-height: 2rem;
		}

		.sapMTokenizer .sapMToken {
			margin-top: 0.1875rem;
		}
	}
}

.sapMInputBase:not(.sapMInputBaseDisabled):not(.sapMInputBaseIconPressed) .sapMInputBaseIconContainer .sapMInputBaseIcon {
	color: var(--sapContent_IconColor);

	&:hover {
		background: var(--sapButton_Lite_Hover_Background);
	}
	&:active {
		background-color: var(--sapButton_Lite_Active_Background);
		color: var(--sapButton_Active_TextColor);
	}
}

.sapMInputBaseIconPressed .sapMInputBaseIcon,
.sapMInputBaseIconPressed .sapMInputBaseIcon:hover {
	background: var(--sapButton_Selected_Background);
	border-left-color: var(--sapButton_Selected_BorderColor);
}

.sapMInputBaseDisabledWrapper .sapMInputBaseIcon {
	color: var(--sapContent_IconColor);

	&:hover {
		background: transparent;
	}
}

/* List specific styles */
.sapMILI-CTX .sapMInputBaseContentWrapper,
.sapMILI-CTX .sapMInputBaseInner,
.sapMILI-CTX .sapMInputBaseDisabled .sapMInputBaseInner,
.sapMILI-CTX .sapMInputBaseReadonlyWrapper .sapMInputBaseInner {
	text-align: right;
	background: transparent;
}

.sapMLIBActive {

	.sapMInputBaseInner,
	.sapMInputBaseContentWrapper {
		color: var(--sapList_Active_TextColor);
		background: transparent;
	}

	.sapMInputDescriptionText {
		color: var(--sapList_Active_TextColor);
	}
}

.sapMLIBActive .sapMInputBaseInner::-webkit-input-placeholder {
	color: var(--sapList_Active_TextColor);
}
/* END "InputBase.less" */


/* note: the following two files are not in alphabetical order and should be imported after InputBase.less */
/* START "ComboBoxBase.less" */
/* ==================================== */
/* CSS for control sap.m/ComboBoxBase   */
/* Fiori 3 theme                        */
/* ==================================== */

.sapMInputBaseIconPressed .sapMComboBoxBaseClearIcon {
	color: var(--sapContent_IconColor);
	background: transparent;

	&:hover {
		background: var(--sapButton_Lite_Hover_Background);
	}

	&:active {
		background-color: var(--sapButton_Lite_Active_Background);
		color: var(--sapButton_Active_TextColor);

		&::before {
			color: var(--sapButton_Active_TextColor);
		}
	}
}

.sapMInputBaseIconPressed .sapMComboBoxBaseClearIcon::before {
	color: var(--sapContent_IconColor);
}
/* END "ComboBoxBase.less" */

/* START "ColumnListItem.less" */
/* ==================================== */
/* CSS for control sap.m/ColumnListItem */
/* Fiori 3 theme                        */
/* ==================================== */

@_sap_m_table_SelectionControlWidth: 2.75rem;

/* selection border indicator */
/* note: adding border-bottom to the td, increased the size of the table, hence not adding border-bottom */
/* note: adding border-top to the sibling row is not suitable as the sibling row can be hidden and in such case the selection border is lost */
.sapMTableTBody:not(.sapMListTblHasPopin) > .sapMLIBSelected,
.sapMTableTBody.sapMListTblHasPopin > .sapMLIBSelected + .sapMListTblSubRow {
	box-shadow: inset 0px -0.0625rem var(--sapList_SelectionBorderColor);
}

/* selection border indicator was not visible on the last row as the td elements within the last row have a bottom border */
/* hence applying -0.125rem so that the selection border is visible */
.sapMTableTBody:not(.sapMListTblHasPopin) > .sapMLIBSelected:last-child,
.sapMTableTBody.sapMListTblHasPopin > .sapMLIBSelected + .sapMListTblSubRow:last-child {
	box-shadow: inset 0px -0.125rem var(--sapList_SelectionBorderColor);
}

/* Safari work-around as box-shadow is not supported on the <tr> element, */
/* hence adding the selection indicator box-shadow to the <td> element */
html[data-sap-ui-browser^="sf"] .sapMTableTBody:not(.sapMListTblHasPopin) > .sapMLIBSelected > td,
html[data-sap-ui-browser^="sf"] .sapMTableTBody.sapMListTblHasPopin > .sapMLIBSelected + .sapMListTblSubRow > td {
	box-shadow: inset 0px -0.0625rem var(--sapList_SelectionBorderColor);
}

/* END "ColumnListItem.less" */

/* START "LightBox.less" */
/* ------------------------------- */
/* CSS for control sap.m/LightBox  */
/* Fiori 3 theme                   */
/* ------------------------------- */

/* ------------------------------- */
/* Variables overriding            */
/* ------------------------------- */

@_sap_m_LightBox_OverlayBackground: fade(@sapUiBlockLayerBackground, 60);
@_sap_m_LightBox_ContainerBackground: var(--sapGroup_ContentBackground);
@_sap_m_LightBox_SubtitleMarginTop: 0.25rem;

/* ------------------------------- */
/* Footer                          */
/* ------------------------------- */

.sapMLightBoxFooter {
	align-items: center;

	.sapMLightBoxTitleSection {
		margin: 0 0 0 1rem;
		padding: 0;
	}

	.sapMBtn {
		margin: 0 1rem 0;
		padding-right: 0;
	}
}

.sapUiSizeCompact {

	.sapMLightBoxFooter {

		.sapMBtn {
			padding-right: 0;
			margin-bottom: 0;
		}
	}
}
/* END "LightBox.less" */

/* START "Link.less" */
/* =========================== */
/* CSS for control sap.m/Link  */
/* Fiori 3 theme               */
/* =========================== */

.sapMLnkDsbl {
	opacity: var(--sapContent_DisabledOpacity);
	outline: none;
	cursor: default;
	text-decoration: none;
}

.sapMLIBActive .sapMLnk {
	color: var(--sapList_Active_TextColor);
	text-decoration: underline;
}

.sapMLnk.sapMLnkSubtle {
	color: var(--sapLink_SubtleColor);
	text-decoration: none;
}

.sapMLnkSubtle:focus {
	color: var(--sapContent_FocusColor);
}

.sapMLnk:not(.sapMLnkDsbl) {
	text-shadow: var(--sapContent_TextShadow);
}

.sapMLnk:hover:not(.sapMLnkDsbl) {
	color: var(--sapLink_Hover_Color);
}

.sapMLnk:active:not(.sapMLnkDsbl),
.sapMLnk:focus:not(.sapMLnkDsbl) {
	color: var(--sapLink_Active_Color);
}

/* align Link in Form with Label */
.sapUiFormEdit .sapMLnk {
	margin-top: 0.875rem; /* don't use padding as this would stretch the focus outline */
	margin-bottom: 0.625rem; /* for some reason browser adds 4px, display: block would lead to stretched focus outline */
}

.sapMListTblRow.sapMLIBSelected .sapMLnk:not(.sapMLnkDsbl) {
	text-shadow: var(--sapContent_TextShadow);
}
/* END "Link.less" */

/* START "ListBase.less" */
/* =============================== */
/* CSS for control sap.m/ListBase  */
/* Fiori 3 theme                   */
/* =============================== */

.sapMGrowingListDescription,
.sapMGrowingListTriggerText > .sapMSLITitle {
	text-shadow: @sapUiShadowText;
}

.sapMSticky > .sapMListHdrText,
.sapMSticky > .sapMListHdrTBar.sapMTB-Transparent-CTX {
	background: lighten(@sapUiListHeaderBackground, 2);
}

.sapMGrowingListTrigger {
	border-top: var(--sapList_BorderWidth) solid var(--sapList_HeaderBorderColor);
}
/* END "ListBase.less" */

/* START "ListItemBase.less" */
/* =================================== */
/* CSS for control sap.m/ListItemBase  */
/* Fiori 3 theme                       */
/* =================================== */

@_sap_m_ListItemBase_ListTextShadowColor: none;
@_sap_m_ListItemBase_DeleteIcon: decline;
@_sap_m_ListItemBase_ButtonMarginTop: 0;
@_sap_m_ListItemBase_SelectionControlWidth: 2.75rem;
@_sap_m_ListItemBase_SelectionControlHeight: 2.75rem;

.sapMLIBCounter {
	text-shadow: @_sap_m_ListItemBase_ListTextShadowColor;
}

.sapMLIB.sapMLIBSelected {
	border-bottom: 0.0625rem solid var(--sapList_SelectionBorderColor);
}

.sapMLIBActive.sapMLIBFocusable:focus {
	outline-color: var(--sapContent_ContrastFocusColor);
}

/* Fix for IE/Edge visual appearance of buttons */
.sapMLIB .sapMBtn:hover .sapMBtnHoverable.sapMBtnTransparent {
	background-clip: border-box;
	border-color: transparent;
}
/* END "ListItemBase.less" */

/* START "MenuButton.less" */
/* ================================= */
/* CSS for control sap.m/MenuButton  */
/* Fiori 3 theme                     */
/* ================================= */

/* Compact size */
.sapUiSizeCompact {

	.sapMMenuBtn {

		.sapMBtnInner.sapMBtnText .sapMBtnIcon {
			margin-left: 0;
			margin-right: 0;
		}
	}

	.sapMMenuBtn .sapMBtnIcon {
		margin-left: 0.4375rem;
		margin-right: 0.4375rem;
	}
}

.sapMMenuBtn.sapMMenuBtnRegular .sapMBtnInner:not(.sapMBtnText) {
	padding-left: 0;
}

.sapMMenuBtn .sapMBtn:not(.sapMSBArrow) .sapMBtnInner.sapMBtnIconFirst:not(.sapMBtnText) .sapMBtnIcon {
	padding-right: 0;
}

/* END "MenuButton.less" */

/* START "MenuListItem.less" */
/* =================================== */
/* CSS for control sap.m/MenuListItem  */
/* Quartz theme                        */
/* =================================== */

.sapMRespMenuDialog .sapMLIB {
	padding: 0 1rem;
}
/* END "MenuListItem.less" */

/* START "MessageBox.less" */
/* ================================= */
/* CSS for control sap.m/MessageBox  */
/* Fiori 3 theme                     */
/* ================================= */

/* header shadow - different states */
@_sap_m_MessageBox_HeaderShadow:  inset 0 -0.0625rem;
@_sap_m_MessageBox_Shadow: @sapUiShadowHeader;
@_sap_m_MessageBox_InformationShadow: @_sap_m_MessageBox_HeaderShadow var(--sapInformationBorderColor), @_sap_m_MessageBox_Shadow;
@_sap_m_MessageBox_WarningShadow: @_sap_m_MessageBox_HeaderShadow var(--sapWarningBorderColor), @_sap_m_MessageBox_Shadow;
@_sap_m_MessageBox_ErrorShadow:  @_sap_m_MessageBox_HeaderShadow var(--sapErrorBorderColor), @_sap_m_MessageBox_Shadow;
@_sap_m_MessageBox_SuccessShadow: @_sap_m_MessageBox_HeaderShadow var(--sapSuccessBorderColor), @_sap_m_MessageBox_Shadow;

.sapMDialog.sapMMessageBoxInfo .sapMDialogIcon.sapUiIcon {
	color: var(--sapInformativeElementColor);
}

.sapMMessageBox .sapMDialogFooter .sapMBtn {
	min-width: 4rem;
}
/* END "MessageBox.less" */

/* START "MessageStrip.less" */
/* =================================== */
/* CSS for control sap.m/MessageStrip  */
/* Fiori 3 theme                       */
/* =================================== */


.sapMMsgStripInformation {
	background-color: var(--sapInformationBackground);
	border-color: var(--sapInformationBorderColor);
	color: var(--sapTextColor);

	& .sapMMsgStripIcon {
		color: var(--sapInformativeElementColor);
	}
}

.sapMMsgStripCloseButton {
	top: -0.4375rem;
}
/* END "MessageStrip.less" */

/* START "MessageView.less" */
/* ================================== */
/* CSS for control sap.m/MessageView  */
/* Fiori 3 theme                      */
/* ================================== */

@_sap_m_MessageView_DescIcon_Width: 1rem;

.sapMMsgView {

	.sapMMsgViewDetailsPage section {
		padding: 1rem;
	}

	.sapMMsgViewItem {
		padding-left: 0;

		&.sapMSLIWithDescription {
			padding-top: 0.5rem;
			padding-bottom: 0.5rem;
		}
	}

	.sapMLIBActive .sapMLIBImgNav {
		background: none;
	}

	.sapMSLITitleOnly {
		padding-top: 0.5rem;
		padding-bottom: 0.5rem;
	}

	.sapMSLITitle {
		color: var(--sapGroup_TitleTextColor);
	}

	.sapMSLIDescription {
		color: var(--sapContent_LabelColor);
	}

	.sapMMsgViewDescriptionText {
		padding-bottom:0;
		margin: 0 0 1rem 2.5rem;
		line-height: 1.4;
		font-family: var(--sapFontFamily);
		color: var(--sapTextColor);
	}

	.sapMMsgViewTitleText {
		margin: 0 0 1rem 2.5rem;
	}

	.sapMMsgViewDescriptionLink {
		margin: 0 0 1rem 2.5rem;
		font-family: var(--sapFontFamily);
		font-size: @sapMFontMediumSize;
		font-weight: normal;
		color: var(--sapLinkColor);
	}

	.sapMSLIWithDescription > .sapMLIBContent > .sapMSLIDiv > .sapMSLIDescription {
		margin-top: 0.25rem;
	}

	.sapMIBar .sapMBarChild {
		margin-left: 0;
		margin-right: 0;
	}
}

.sapMMsgView .sapMIBar.sapMHeader-CTX {
	background-color: var(--sapGroup_ContentBackground);
	padding-left: 1rem;
}

.sapMMsgViewDescIcon {
	margin: 0 1rem 0 1.5rem;
	font-size: 1rem;
	top: 1.125rem;
}

.sapMMsgViewItem .sapMSLIImgIcon {
	font-size: 1rem;
}

.sapMMsgView .sapMSegBBtn .sapMBtnCustomIcon {
	font-size: 1rem;
}

/* Compact size */
.sapUiSizeCompact .sapMMsgView {

	.sapMMsgViewDescIcon {
		line-height: 1rem;
	}
}
/* END "MessageView.less" */

/* START "NewsContent.less" */
/* ================================== */
/* CSS for control sap.m/NewsContent  */
/* Fiori 3 theme                      */
/* ================================== */

@_sap_m_NewsContent_HeaderTextColor: contrast(@_sap_m_TileContent_NewsContentBackgroundColor, @sapUiTileTitleTextColor, @sapUiContentContrastTextColor, @sapUiContentContrastTextThreshold);
@_sap_m_NewsContent_SubHeaderTextColor: contrast(@_sap_m_TileContent_NewsContentBackgroundColor, @sapUiTileTextColor, @sapUiContentContrastTextColor, @sapUiContentContrastTextThreshold);

.sapMNwC {
	background-color: var(--sapTile_OverlayBackground);
	opacity: 0.8;
	height: 3.625rem;
}

.sapMTileCnt.News {

	.sapMNwC {

		.sapMNwCSbh {
			color: var(--sapTile_OverlayForegroundColor);
			line-height: normal;
		}

		.sapMNwCCTxt .sapMText,
		.sapMNwCCTxt .sapMFT {
			color: var(--sapTile_OverlayForegroundColor);
			line-height: normal;
		}
	}
}
/* END "NewsContent.less" */

/* START "NotificationListGroup.less" */
/* ====================================== */
/* CSS for control sap.m/NotificationListGroup  */
/* Fiori 3 theme                          */
/* ====================================== */

@_sap_m_NotificationListGroup_Background: var(--sapList_GroupHeaderBackground);
/* END "NotificationListGroup.less" */

/* START "ObjectAttribute.less" */
/* ====================================== */
/* CSS for control sap.m/ObjectAttribute  */
/* Fiori 3 theme                          */
/* ====================================== */

@_sap_m_ObjectAttribute_ListTextShadowColor: none;

.sapMObjectAttributeActive .sapMObjectAttributeText:focus {
	position: relative;
}

.sapMObjectAttributeActive .sapMObjectAttributeText:focus::after {
	pointer-events: none;
	display: block;
	content: '';
	position: absolute;
	top: 1px;
	left: 1px;
	bottom: 1px;
	right: 1px;
	outline: 1px dotted var(--sapContent_FocusColor);
}

.sapMObjectAttributeActive .sapMObjectAttributeText:active,
.sapMObjectAttributeActive .sapMObjectAttributeText:hover {
	text-decoration: underline;
	color: var(--sapLink_Hover_Color);
}

/*=========================================== */
/* Custom design for Responsive Object Header */
/*=========================================== */

.sapMOHR .sapMObjectAttributeActive .sapMObjectAttributeText:active,
.sapMOHR .sapMObjectAttributeActive .sapMObjectAttributeText:hover,
.sapMOHR .sapMObjectAttributeActive .sapMObjectAttributeText:focus {
	text-decoration: underline;
	color: var(--sapLink_Hover_Color);
}

/*=========================================== */
/* Custom design for Static Object Header     */
/*=========================================== */

.sapMOH .sapMObjectAttributeActive .sapMObjectAttributeText:active,
.sapMOH .sapMObjectAttributeActive .sapMObjectAttributeText:hover {
	text-decoration: underline;
	color: var(--sapLink_Hover_Color);
}

.sapMOHR .sapMObjectAttributeActive .sapMObjectAttributeText,
.sapMOH .sapMObjectAttributeActive .sapMObjectAttributeText {
	text-shadow: @_sap_m_ObjectAttribute_ListTextShadowColor;
}
/* END "ObjectAttribute.less" */

/* START "ObjectHeader.less" */
/* =================================== */
/* CSS for control sap.m/ObjectHeader  */
/* Fiori 3 theme                       */
/* =================================== */

.sapMOH.sapMOHBgTranslucent,
.sapMOHC.sapMOHBgTranslucent,
.sapMOH.sapMOHBgSolid,
.sapMOHC.sapMOHBgSolid {
	background-color: var(--sapObjectHeader_Background);
}

.sapMOHC.sapMOHBgTranslucent,
.sapMOHC.sapMOHBgSolid {
	border: none;
	box-shadow: none;
}

.sapMOH.sapMOHBgTransparent,
.sapMOHC.sapMOHBgTransparent {
	background: transparent;
}

a.sapMOHTitle.sapMOHTitleActive:hover > h1 .sapMText {
	text-decoration: underline;
}

.sapMOHTitleArrow > .sapUiIcon {
	outline-offset: -1px;
}

.sapMOHTitle.sapMOHTitleActive:focus {
	outline: none;
}

.sapMOHTitle.sapMOHTitleActive:focus > h1 span,
.sapMOHTitle.sapMOHTitleActive:focus > h2 span,
.sapMOHTitle.sapMOHTitleActive:focus > h3 span,
.sapMOHTitle.sapMOHTitleActive:focus > h4 span,
.sapMOHTitle.sapMOHTitleActive:focus > h5 span,
.sapMOHTitle.sapMOHTitleActive:focus > h6 span,
.sapMOHIcon.sapMPointer .sapUiIcon.sapUiIconPointer:focus,
.sapMOHTitleArrow .sapUiIcon:focus {
	outline: 1px dotted var(--sapContent_FocusColor);
	outline-offset: -1px;
}

/* styles for responsive object header */
.sapMOHRTitle h1 {
	font-size: var(--sapFontHeader3Size);
}

.sapMOHR:not(.sapMOHRNoBorder) {
	box-shadow: @sapUiShadowHeader;
}

.sapMOHR.sapMOHRBgSolid,
.sapMOHR.sapMOHRBgTranslucent {
	background: var(--sapObjectHeader_Background);
}

.sapMOHR.sapMOHRBgTransparent {
	background: transparent;
}

.sapMOHRTitleArrow .sapUiIcon:focus {
	outline: 1px dotted var(--sapContent_FocusColor);
	outline-offset: -1px;
}

.sapMOHRIcon.sapMPointer .sapUiIcon.sapUiIconPointer:focus {

	&::before {
		outline: 1px dotted var(--sapContent_FocusColor);
	}
}

.sapMOHRTitleActive .sapMOHRTitleText:focus {
	outline: 1px dotted var(--sapContent_FocusColor);
	outline-offset: -1px;
}
/* END "ObjectHeader.less" */

/* START "ObjectMarker.less" */
/* =================================== */
/* CSS for control sap.m/ObjectMarker  */
/* Fiori 3 theme                       */
/* =================================== */

@_sap_m_ObjectMarker_LinkShadowColor: none;

.sapMObjectMarker .sapMLnk {
	text-shadow: @_sap_m_ObjectMarker_LinkShadowColor;
}
/* END "ObjectMarker.less" */

/* START "ObjectNumber.less" */
/* =================================== */
/* CSS for control sap.m/ObjectNumber  */
/* Fiori 3 theme                       */
/* =================================== */

.sapMObjectNumberInverted .sapMObjectNumberText,
.sapMObjectNumberInverted .sapMObjectNumberUnit {
	text-shadow: var(--sapContent_ContrastTextShadow);
}
/* END "ObjectNumber.less" */

/* START "ObjectStatus.less" */
/* =================================== */
/* CSS for control sap.m/ObjectStatus  */
/* Fiori 3 theme                       */
/* =================================== */

.sapMObjStatusInverted .sapMObjStatusText,
.sapMObjStatusInverted .sapMObjStatusIcon {
	min-height: 1rem;
}

.sapMObjectStatusLarge {

	.sapMObjStatusTitle,
	.sapMObjStatusText,
	.sapMObjStatusIcon {
		font-size: 1.5rem;
		line-height: 2rem;
		min-height: 2rem;
	}

	.sapMObjStatusIcon > .sapUiIcon {
		font-size: 1.5rem;
	}
}

.sapMObjectStatusLarge.sapMObjStatusInverted {

	.sapMObjStatusIcon > .sapUiIcon {
		vertical-align: bottom;
		font-size: 1.25rem;
		padding-left: 0;
		padding-right: 0;
	}

	.sapMObjStatusIcon:not(.sapMObjStatusIconOnly) {
		padding-left: 0;
		padding-right: 0;
	}
}

.sapMObjStatusInverted {
	min-width: 1.25rem;
}

.sapMObjStatusWrapper {
	border-radius: var(--sapElement_BorderCornerRadius);
}

.sapMObjStatusInverted .sapMObjStatusText,
.sapMObjStatusInverted .sapMObjStatusIcon {
	color: var(--sapContent_ContrastTextColor);
}

.sapMObjStatusNone:not(.sapMObjStatusInverted) {

	.sapUxAPObjectPageContainer &,
	.sapUxAPObjectPageHeaderContentItem &,
	&.sapUxAPObjectPageHeaderContentItem,
	.sapUxAPObjectPageHeaderDetails .sapFDynamicPageHeaderContent & {

		.sapMObjStatusText,
		.sapMObjStatusIcon {
			color: var(--sapNeutralTextColor);
		}
	}
}

.sapMListTblCell {

	.sapMObjStatus.sapMObjStatusInverted {

		.sapMObjStatusIcon {
			vertical-align: middle;
		}
	}
}

.sapMObjStatusInverted .sapMObjStatusText,
.sapMObjStatusInverted .sapMObjStatusIcon,
.sapMObjStatusInverted .sapMObjStatusLink:active .sapMObjStatusText,
.sapMObjStatusInverted .sapMObjStatusLink:active .sapMObjStatusIcon {
	text-shadow: var(--sapContent_ContrastTextShadow);
}

/*  Second set of inverted indication colors regular state */
.sapMObjStatusInverted.sapMObjStatusIndication11 .sapMObjStatusText,
.sapMObjStatusInverted.sapMObjStatusIndication11 .sapMObjStatusIcon,
.sapMObjStatusInverted.sapMObjStatusIndication12 .sapMObjStatusText,
.sapMObjStatusInverted.sapMObjStatusIndication12 .sapMObjStatusIcon,
.sapMObjStatusInverted.sapMObjStatusIndication13 .sapMObjStatusText,
.sapMObjStatusInverted.sapMObjStatusIndication13 .sapMObjStatusIcon,
.sapMObjStatusInverted.sapMObjStatusIndication14 .sapMObjStatusText,
.sapMObjStatusInverted.sapMObjStatusIndication14 .sapMObjStatusIcon,
.sapMObjStatusInverted.sapMObjStatusIndication15 .sapMObjStatusText,
.sapMObjStatusInverted.sapMObjStatusIndication15 .sapMObjStatusIcon,
.sapMObjStatusInverted.sapMObjStatusIndication16 .sapMObjStatusText,
.sapMObjStatusInverted.sapMObjStatusIndication16 .sapMObjStatusIcon,
.sapMObjStatusInverted.sapMObjStatusIndication17 .sapMObjStatusText,
.sapMObjStatusInverted.sapMObjStatusIndication17 .sapMObjStatusIcon,
.sapMObjStatusInverted.sapMObjStatusIndication18 .sapMObjStatusText,
.sapMObjStatusInverted.sapMObjStatusIndication18 .sapMObjStatusIcon,
.sapMObjStatusInverted.sapMObjStatusIndication19 .sapMObjStatusText,
.sapMObjStatusInverted.sapMObjStatusIndication19 .sapMObjStatusIcon,
.sapMObjStatusInverted.sapMObjStatusIndication20 .sapMObjStatusText,
.sapMObjStatusInverted.sapMObjStatusIndication20 .sapMObjStatusIcon {
	text-shadow: var(--sapContent_TextShadow);
}

.sapMObjStatusInverted.sapMObjStatusIndication11 .sapMObjStatusLink:active .sapMObjStatusText,
.sapMObjStatusInverted.sapMObjStatusIndication11 .sapMObjStatusLink:active .sapMObjStatusIcon,
.sapMObjStatusInverted.sapMObjStatusIndication12 .sapMObjStatusLink:active .sapMObjStatusText,
.sapMObjStatusInverted.sapMObjStatusIndication12 .sapMObjStatusLink:active .sapMObjStatusIcon,
.sapMObjStatusInverted.sapMObjStatusIndication13 .sapMObjStatusLink:active .sapMObjStatusText,
.sapMObjStatusInverted.sapMObjStatusIndication13 .sapMObjStatusLink:active .sapMObjStatusIcon,
.sapMObjStatusInverted.sapMObjStatusIndication14 .sapMObjStatusLink:active .sapMObjStatusText,
.sapMObjStatusInverted.sapMObjStatusIndication14 .sapMObjStatusLink:active .sapMObjStatusIcon,
.sapMObjStatusInverted.sapMObjStatusIndication15 .sapMObjStatusLink:active .sapMObjStatusText,
.sapMObjStatusInverted.sapMObjStatusIndication15 .sapMObjStatusLink:active .sapMObjStatusIcon,
.sapMObjStatusInverted.sapMObjStatusIndication16 .sapMObjStatusLink:active .sapMObjStatusText,
.sapMObjStatusInverted.sapMObjStatusIndication16 .sapMObjStatusLink:active .sapMObjStatusIcon,
.sapMObjStatusInverted.sapMObjStatusIndication17 .sapMObjStatusLink:active .sapMObjStatusText,
.sapMObjStatusInverted.sapMObjStatusIndication17 .sapMObjStatusLink:active .sapMObjStatusIcon,
.sapMObjStatusInverted.sapMObjStatusIndication18 .sapMObjStatusLink:active .sapMObjStatusText,
.sapMObjStatusInverted.sapMObjStatusIndication18 .sapMObjStatusLink:active .sapMObjStatusIcon,
.sapMObjStatusInverted.sapMObjStatusIndication19 .sapMObjStatusLink:active .sapMObjStatusText,
.sapMObjStatusInverted.sapMObjStatusIndication19 .sapMObjStatusLink:active .sapMObjStatusIcon,
.sapMObjStatusInverted.sapMObjStatusIndication20 .sapMObjStatusLink:active .sapMObjStatusText,
.sapMObjStatusInverted.sapMObjStatusIndication20 .sapMObjStatusLink:active .sapMObjStatusIcon {
	text-shadow: var(--sapContent_ContrastTextShadow);
	color: var(--sapIndicationColor_10_Active_TextColor);
}
/* END "ObjectStatus.less" */

/* START "OverflowToolbarAssociativePopover.less" */
/* ======================================================== */
/* CSS for control sap.m/OverflowToolbarAssociativePopover  */
/* Fiori 3 theme                                            */
/* ======================================================== */

html.sap-phone {

	.sapMOTAPopover {

		&.sapMOTAPopoverNoShadowTop {
			border-radius: 0 0 0.25rem 0.25rem;
		}

		&.sapMOTAPopoverNoShadowBottom {
			border-radius: 0.25rem 0.25rem 0 0;
		}
	}
}
/* END "OverflowToolbarAssociativePopover.less" */

/* START "Page.less" */
/* =================================== */
/* CSS for control sap.m/Page.control  */
/* Fiori 3 theme                       */
/* =================================== */

.sapMPage .sapMPageHeader:not(.sapMIBar-CTX),
.sapMPageWithSubHeader .sapMPageSubHeader:not(.sapMIBar-CTX) {
	position: relative;
	border-bottom: none;
	box-shadow: none;

	.sapMIBar-CTX {
		position: relative;
		z-index: 2;
	}

	&::after {
		content: '';
		position: absolute;
		height: 1px;
		bottom: 0;
		width: 100%;
		box-shadow: inset 0 -0.0625rem var(--sapPageHeader_BorderColor), 0 0 0.25rem 0 fade(@sapUiContentShadowColor, 15);
		z-index: 1;
	}
}

.sapMPageWithHeader.sapMPageWithSubHeader {

	.sapMPageHeader {
		box-shadow: none;

		&::after {
			box-shadow: none;
		}
	}
}

.sapMPageBgStandard {
	background-color: var(--sapBackgroundColor);
}

.sapMPageBgSolid {
	background-color: var(--sapBackgroundColor);
}

.sapMPageBgTransperant {
	background-color: transparent;
}

.sapMPageBgList {
	background-color: var(--sapGroup_ContentBackground);
}

/* The following overrides for sap_belize/sap_belize_plus are only intended for apps inside FLP (Ushell) */
.sapUshellShell {

	/* In sap_belize_plus backgroundDesign=Standard maps to Solid */
	.sapMPageBgStandard {
		background-color: var(--sapBackgroundColor);
	}

	/* For the pages in the master part of sap.m.SplitApp backgroundDesign=Standard maps to Transparent */
	.sapMSplitContainerMaster .sapMPageBgStandard {
		background-color: transparent;
		background-image: none;
	}

	/* Hack - temporary - this is the FLP change*/
	#sapUshellDashboardPage {
		background-color: transparent !important;
		background-image: none !important;
	}
}

.sapMPageWithFloatingFooter .sapMPageFloatingFooter {
	opacity: 1;

	.sapMIBar-CTX.sapMFooter-CTX {
		box-shadow: var(--sapContent_Shadow1);
		border: none;
	}
}

html[data-sap-ui-animation='on'] .sapMPageWithFloatingFooter {

	@keyframes bounceShow {

		0% {
			transform: translateY(100%);
			opacity: 0;
		}

		100% {
			opacity: 1;
		}
	}

	@keyframes bounceHide {

		0% {
			transform: translateY(-5%);
			opacity: 1;
		}

		100% {
			transform: translateY(100%);
			opacity: 0;
		}
	}
}

.sapMPage.sapF2CollapsedHeader > .sapMPageHeader {

	& + section,
	& + .sapUiHiddenPlaceholder + section {
		top: 0;
	}

	& + .sapMPageSubHeader + section {
		top: 2.75rem;
	}
}

.sapMPage.sapF2CollapsedHeader > .sapMPageHeader {

	& + section,
	& + .sapUiHiddenPlaceholder + section {
		top: 0;
	}

	& + .sapMPageSubHeader + section {
		top: 2.75rem;
	}
}

/* page with footer */
.sapMPageWithFooter > section {
	bottom: 2.75rem;
}

.sapMPage {

	> .sapMPageHeader + section,
	> .sapMPageSubHeader + section,
	> .sapMPageHeader + .sapUiHiddenPlaceholder + section {
		top: 2.75rem;
	}

	> .sapMPageHeader + .sapMPageSubHeader + section {
		top: 5.5rem;
	}

	> .sapMPageHeader + .sapMPageSubHeader.sapMPageSubHeaderInfoBar + section {
		top: 4.75rem;
	}
}

.sapUiSizeCompact .sapF2CollapsedHeader.sapMPageWithHeader {

	> section {
		top: 0;
	}

	&.sapMPageWithSubHeader > section {
		top: 2rem;
	}
}

.sapMPageWithHeader {

	&.sapFShellBar-CTX > section {
		top: 2.75rem;
	}

	&.sapMPageWithSubHeader.sapFShellBar-CTX > section {
		top: 5.5rem;
	}
}

.sapMPageHeader,
.sapMPageSubHeader,
.sapMPageFooter {

	.sapUi-Std-PaddingS,
	.sapUi-Std-PaddingM,
	.sapUi-Std-PaddingL,
	.sapUi-Std-PaddingXL {

		&.sapMBar {
			box-sizing: border-box;

			.sapMBarLeft {
				padding-left: inherit;
			}

			.sapMBarRight {
				padding-right: inherit;
			}
		}
	}
}

.sapUi-Std-PaddingS,
.sapUi-Std-PaddingM,
.sapUi-Std-PaddingL,
.sapUi-Std-PaddingXL {

	&.sapMPageFloatingFooter.sapMPageFooter {
		margin: 0.5rem 0;
		width: auto;
	}
}

/* Compact size */
.sapUiSizeCompact {
	/* Header and footer have 2.5 rem */
	.sapMPageWithHeader > section {
		top: 2.5rem;
	}

	.sapMPageWithFooter > section {
		bottom: 2.5rem;
	}

	/* Subheader only 2 rem */
	.sapMPageWithSubHeader > section {
		top: 2rem;
	}

	.sapMPageWithHeader {

		&.sapFShellBar-CTX > section {
			top: 2.75rem;
		}

		&.sapMPageWithSubHeader.sapFShellBar-CTX > section {
			top: 5.25rem;
		}
	}
}
/* END "Page.less" */

/* START "Panel.less" */
/* ================================== */
/* Theme CSS for control sap.m/Panel  */
/* Fiori 3 theme                      */
/* ================================== */

.sapMPanel {
	min-height: 2.5rem;
}

.sapMPanelBGSolid {
	background-color: var(--sapGroup_ContentBackground);
}

.sapMPanelBGTranslucent {
	/* In order to avoid over-styling, we need to change the default behavior to transparent for belize.
	We cannot change it via the design property, because this change will be backward incompatible.*/
	background-color: transparent;
}

.sapMPanelBGTransparent {
	background-color: transparent;
}

/* if Panel is not expandable, we do wish header to come with own border */
.sapMPanel .sapMPanelHeadingDiv > .sapMPanelHdr,
/* notice: sapMPanelWrappingDiv is available if Panel is expandable */
.sapMPanelWrappingDiv,
/* do not want border if expanded and if only header text */
.sapMPanelWrappingDivTb {
	border-bottom: 0.0625rem solid var(--sapGroup_TitleBorderColor);
}

.sapMPanelContent:not(.sapMPanelBGTransparent) {
	border-bottom: 0.0625rem solid var(--sapGroup_TitleBorderColor);
}

.sapMPanel .sapMPanelHdr {
	line-height: 2.75rem;
	height: 2.75rem;
}
/* END "Panel.less" */

/* START "PlanningCalendar.less" */
/* ======================================= */
/* CSS for control sap.m/PlanningCalendar  */
/* Fiori 3 theme                           */
/* ======================================= */

/* show every second row in an other color */
.sapMPlanCal:not(.sapMPlanCalSuppressAlternatingRowColors) > .sapMList > table > tbody > tr.sapMLIB:nth-child(even):not(.sapMListTblSubRow),
.sapMSize0.sapMPlanCal:not(.sapMPlanCalSuppressAlternatingRowColors) > .sapMList > table > tbody > tr.sapMLIB:nth-child(4n+3),
.sapMSize1.sapMPlanCal:not(.sapMPlanCalSuppressAlternatingRowColors) > .sapMList > table > tbody > tr.sapMLIB:nth-child(4n+3),
.sapMPlanCal:not(.sapMPlanCalSuppressAlternatingRowColors) > .sapMList > table > tbody > tr.sapMListTblSubRow:nth-child(4n) {
	background-color: var(--sapList_AlternatingBackground);
}

.sapMPlanCal:not(.sapMPlanCalSuppressAlternatingRowColors) > .sapMList > table > tbody > tr:nth-child(even):not(.sapMListTblSubRow).sapMLIBHoverable:hover,
.sapMSize0.sapMPlanCal:not(.sapMPlanCalSuppressAlternatingRowColors) > .sapMList > table > tbody > tr:nth-child(4n+3).sapMLIBHoverable:hover,
.sapMSize0.sapMPlanCal:not(.sapMPlanCalSuppressAlternatingRowColors) > .sapMList > table > tbody > tr:nth-child(4n+3).sapMLIBHoverable:hover + .sapMListTblSubRow,
.sapMSize1.sapMPlanCal:not(.sapMPlanCalSuppressAlternatingRowColors) > .sapMList > table > tbody > tr:nth-child(4n+3).sapMLIBHoverable:hover,
.sapMSize1.sapMPlanCal:not(.sapMPlanCalSuppressAlternatingRowColors) > .sapMList > table > tbody > tr:nth-child(4n+3).sapMLIBHoverable:hover + .sapMListTblSubRow,
.sapMPlanCal:not(.sapMPlanCalSuppressAlternatingRowColors) > .sapMList > table > tbody > tr.sapMListTblSubRow:nth-child(4n).sapMLIBHoverable:hover {
	background-color: var(--sapList_Hover_Background);
}

.sapMPlanCal:not(.sapMPlanCalSuppressAlternatingRowColors) > .sapMList > table > tbody > tr:nth-child(even):not(.sapMListTblSubRow).sapMLIBSelected,
.sapMPlanCal:not(.sapMPlanCalSuppressAlternatingRowColors) > .sapMList > table > tbody > tr:not(.sapMListTblSubRow).sapMLIBSelected,
.sapMSize0.sapMPlanCal:not(.sapMPlanCalSuppressAlternatingRowColors) > .sapMList > table > tbody > tr:nth-child(4n+3).sapMLIBSelected,
.sapMSize0.sapMPlanCal:not(.sapMPlanCalSuppressAlternatingRowColors) > .sapMList > table > tbody > tr:nth-child(4n+3).sapMLIBSelected + .sapMListTblSubRow,
.sapMSize1.sapMPlanCal:not(.sapMPlanCalSuppressAlternatingRowColors) > .sapMList > table > tbody > tr:nth-child(4n+3).sapMLIBSelected,
.sapMSize1.sapMPlanCal:not(.sapMPlanCalSuppressAlternatingRowColors) > .sapMList > table > tbody > tr:nth-child(4n+3).sapMLIBSelected + .sapMListTblSubRow,
.sapMPlanCal:not(.sapMPlanCalSuppressAlternatingRowColors) > .sapMList > table > tbody > tr.sapMListTblSubRow:nth-child(4n).sapMLIBSelected {
	background-color: var(--sapList_SelectionBackgroundColor);
}

.sapMPlanCal:not(.sapMPlanCalSuppressAlternatingRowColors) > .sapMList > table > tbody > tr:nth-child(even):not(.sapMListTblSubRow).sapMLIBSelected.sapMLIBHoverable:hover,
.sapMPlanCal:not(.sapMPlanCalSuppressAlternatingRowColors) > .sapMList > table > tbody > tr:not(.sapMListTblSubRow).sapMLIBSelected.sapMLIBHoverable:hover,
.sapMSize0.sapMPlanCal:not(.sapMPlanCalSuppressAlternatingRowColors) > .sapMList > table > tbody > tr:nth-child(4n+3).sapMLIBSelected.sapMLIBHoverable:hover,
.sapMSize0.sapMPlanCal:not(.sapMPlanCalSuppressAlternatingRowColors) > .sapMList > table > tbody > tr:nth-child(4n+3).sapMLIBSelected.sapMLIBHoverable:hover + .sapMListTblSubRow,
.sapMSize1.sapMPlanCal:not(.sapMPlanCalSuppressAlternatingRowColors) > .sapMList > table > tbody > tr:nth-child(4n+3).sapMLIBSelected.sapMLIBHoverable:hover,
.sapMSize1.sapMPlanCal:not(.sapMPlanCalSuppressAlternatingRowColors) > .sapMList > table > tbody > tr:nth-child(4n+3).sapMLIBSelected.sapMLIBHoverable:hover + .sapMListTblSubRow,
.sapMPlanCal:not(.sapMPlanCalSuppressAlternatingRowColors) > .sapMList > table > tbody > tr.sapMListTblSubRow:nth-child(4n).sapMLIBSelected.sapMLIBHoverable:hover {
	background-color: @sapUiListSelectionHoverBackground;
}

/* Calendar overstyling */

html.sap-desktop .sapMPlanCal .sapUiCalItem:not(.sapUiCalItemSel):hover {
	background-color: var(--sapList_Hover_Background);
}

html.sap-desktop .sapMPlanCal .sapUiCalItemWeekEnd:not(.sapUiCalItemSel):hover {
	background-color: var(--sapList_Hover_Background);
}

html.sap-desktop .sapMPlanCal .sapUiCalItemOtherMonth:not(.sapUiCalItemSel):hover {
	background-color: var(--sapList_AlternatingBackground);
}

.sapMPlanCal .sapMPlanCalRowHead .sapMSLIImg {
	border-radius: 0.25rem;
	height: auto;
	width: 3rem;
	line-height: 3rem;
}

.sapMPlanCal .sapMListTbl .sapMSLIImgIcon.sapUiIcon:not(.sapMLIBImgNav):not(.sapMBtnIcon) {
	border-radius: 0.25rem;
	background-color: var(--sapAccentColor7);
	color: var(--sapContent_ContrastTextColor);
	font-size: var(--sapFontHeader4Size);
}

.sapMPlanCalRowHead .sapMSLI,
.sapUiSizeCompact .sapMPlanCalRowHead .sapMSLI {
	height: auto;
}
/* END "PlanningCalendar.less" */

/* START "Popover.less" */
/* ============================== */
/* CSS for control sap.m/Popover  */
/* Fiori 3 theme                  */
/* ============================== */

.sapMPopoverArr::after {
	background: var(--sapGroup_ContentBackground);
	box-shadow: var(--sapContent_Shadow2);
}

.sapMPopoverWithBar > .sapMPopoverArr.sapMPopoverArrUp::after {
	background-color: var(--sapPageHeader_Background);
}

.sapUiSizeCompact {

	.sapMPopoverFooter,
	.sapMPopoverHeader {
		.sapMIBar,
		.sapMBar {
			height: 2.5rem;

			& > .sapMBarLeft,
			& > .sapMBarRight {
				height: 2.5rem;
				line-height: 2.5rem;

				.sapMBtn {
					vertical-align: middle;
				}
			}

			& > .sapMBarMiddle .sapMBarPH {
				height: 2.5rem;
				line-height: 2.5rem;

				.sapMBtn {
					vertical-align: middle;
				}
			}
		}
	}
}

.sapMPopoverHeader,
.sapMPopoverSubHeader  {
	position: relative;
	z-index: 2;

	.sapMBar {

		.sapMBarContainer {
			padding-left: 0;
			padding-right: 0;
		}

		.sapMBarLeft {
			padding-left: 1rem;
		}

		.sapMBarMiddle .sapMBarContainer {
			padding: 0 1rem;
		}

		.sapMBarRight {
			padding-right: 1rem;
		}
	}
}

.sapMPopoverHeader,
.sapMPopoverFooter,
.sapMPopoverSubHeader {

	.sapUi-Std-PaddingS,
	.sapUi-Std-PaddingM,
	.sapUi-Std-PaddingL,
	.sapUi-Std-PaddingXL {

		&.sapMBar {

			.sapMBarMiddle .sapMBarPH {
				padding-left: 0;
				padding-right: 0;
			}

			.sapMBarLeft {
				padding-left: inherit;

				.sapMBarChild {
					padding-right: 0.5rem;
				}
			}

			.sapMBarRight {
				padding-right: inherit;

				.sapMBarChild {
					padding-left: 0.5rem;
				}
			}
		}
	}
}
/* END "Popover.less" */

/* START "ProgressIndicator.less" */
/* ======================================== */
/* CSS for control sap.m/ProgressIndicator  */
/* Fiori 3 theme                            */
/* ======================================== */
@sapMPITextLeftTextThreshold: 0.5;

.sapMPITextLeft,
.sapMPITextRight {
	padding: 0;
	margin-left: 0.375rem;
	margin-right: 0.375rem;
}

.sapMPI {
	height: 1rem;
	min-width: 4rem;

	&:not(.sapMPIDisplayOnly) {
		margin: 0.5rem 0;
	}
}

.sap-phone,
.sap-tablet:not(.sap-combi) {

	.sapMPI:not(.sapMPIDisplayOnly) {
		margin: 0.875rem 0;
	}
}
/* END "ProgressIndicator.less" */

/* START "PullToRefresh.less" */
/* ==================================== */
/* CSS for control sap.m/PullToRefresh  */
/* Fiori 3 theme                        */
/* ==================================== */

.sapMPullDown {
	background-color: darken(@sapUiGroupContentBackground, 5);
	border-bottom: none;
}
/* END "PullToRefresh.less" */

/* START "QuickView.less" */
/* ================================ */
/* CSS for control sap.m/QuickView  */
/* Fiori 3 theme                    */
/* ================================ */

@_sap_m_QuickView_HorizontalLayoutMarginBottom: 1rem;
@_sap_m_QuickView_HorizontalLayoutIconFontSize: 1.5rem;
@_sap_m_QuickView_PagePaddingTop: 2.75rem;
@_sap_m_QuickViewCard_PagePadding: 1rem;

.sapMQuickViewCard {
	background: var(--sapGroup_ContentBackground);
	box-shadow: @sapUiShadowLevel0;
	border-radius: var(--sapElement_BorderCornerRadius);
}
/* END "QuickView.less" */

/* START "RadioButton.less" */
/* ================================== */
/* CSS for control sap.m/RadioButton  */
/* Fiori 3 theme                      */
/* ================================== */

.sapMRb {
	height: 2.75rem;

	.sapMRbBOut {
		stroke-width: 0.125rem;
	}

	&:not(.sapMRbErr):not(.sapMRbWarn):not(.sapMRbInfo) {

		.sapMRbBOut {
			stroke-width: var(--sapField_BorderWidth);
		}
	}
}

.sapMRb .sapMRbB {
	height: 2.75rem;
	line-height: 2.75rem;
	width: 2.75rem;
}

.sapMRb > .sapMRbBLabel {
	line-height: 2.75rem;
	height: 2.75rem;
}

.sapMRbSvg {
	margin: 0.6875rem;
}

.sapMRbHasLabel.sapMRb:focus::before {
	bottom: .5rem;
	top: 0.5rem;
	left: 0.5rem;
	right: 0;
}

/* Right to left */
.sapMRbG[dir=rtl] .sapMRbHasLabel.sapMRb:focus::before {
	left: 0;
	right: 0.5rem;
}

.sapMRbHasLabel .sapMRbB {
	width: 2.75rem;
}

/* Align RadioButton in Form with other controls */
.sapUiForm.sapUiFormEdit-CTX {

	.sapMRb > .sapMRbB {
		width: 2.1875rem;
	}
}

.sapUiSizeCompact {

	.sapMRbB {
		height:2rem;
		line-height: 2rem;
		width: 2rem;
	}

	.sapMRb > .sapMLabel {
		height: 2rem;
		line-height: 2rem;
	}

	.sapMRb:focus::before {
		bottom: 0.325rem;
		top: 0.325rem;
		left: 0.325rem;
		right: 0.325rem;
	}
}

.sapMRb:not(.sapMRbErr):not(.sapMRbWarn):not(.sapMRbInfo):not(.sapMRbSucc) .sapMRbHoverable:hover .sapMRbBOut {
	stroke: var(--sapField_Hover_BorderColor);
	fill: var(--sapField_Hover_Background);
}

.sapMRb:focus::before {
	border: var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);
	bottom: 0.5rem;
	top: 0.5rem;
	left: 0.5rem;
	right: 0.5rem;
}

.sapMLIBActive .sapMRbB .sapMRbBOut {
	border: 1px solid var(--sapList_Active_TextColor);
}

.sapMLIBActive .sapMRbSel .sapMRbBOut {
	background-color: var(--sapList_Active_Background);
}

.sapMRbDis {
	opacity: var(--sapContent_DisabledOpacity);
}

/* Read Only */
.sapMRb.sapMRbRo {

	.sapMRbBOut {
		stroke-dasharray: 4,2;
	}
}

/* Value states */

.sapMRbErr.sapMRbSel,
.sapMRbErr.sapMRbSel.sapMRbRo {

	.sapMRbBInn {
		fill: var(--sapField_InvalidColor);
		stroke: none;
	}
}

.sapMRbErr,
.sapMRbErr.sapMRbBTouched {

	.sapMRbB .sapMRbBOut {
		stroke: var(--sapField_InvalidColor);
		fill: var(--sapField_InvalidBackground);
	}
}

.sapMRbWarn.sapMRbSel,
.sapMRbWarn.sapMRbSel.sapMRbRo {

	.sapMRbBInn {
		fill: var(--sapField_TextColor);
		stroke: none;
	}
}

.sapMRbWarn,
.sapMRbWarn.sapMRbBTouched {

	.sapMRbB .sapMRbBOut {
		stroke: var(--sapField_WarningColor);
		fill: var(--sapField_WarningBackground);
	}
}

.sapMRbSucc.sapMRbSel,
.sapMRbSucc.sapMRbSel.sapMRbRo {

	.sapMRbBInn {
		fill: var(--sapField_SuccessColor);
		stroke: none;
	}
}

.sapMRbSucc,
.sapMRbSucc.sapMRbBTouched {

	.sapMRbB .sapMRbBOut {
		stroke: var(--sapField_SuccessColor);
		fill: var(--sapField_SuccessBackground);
	}
}

.sapMRbInfo.sapMRbSel,
.sapMRbInfo.sapMRbSel.sapMRbRo {

	.sapMRbBInn {
		fill: var(--sapField_InformationColor);
		stroke: none;
	}
}

.sapMRbInfo,
.sapMRbInfo.sapMRbBTouched {

	.sapMRbB .sapMRbBOut {
		stroke: var(--sapField_InformationColor);
		fill: var(--sapField_InformationBackground);
	}
}
/* END "RadioButton.less" */

/* START "RadioButtonGroup.less" */
/* ================================== */
/* CSS for control sap.m/RadioButtonGroup  */
/* Fiori 3 theme                      */
/* ================================== */

@_sap_m_RadioButtonGroup_WidthWithLabel: 2.75rem;
@_sap_m_RadioButtonGroup_PaddingLeftLabel: 2.75rem;
@_sap_m_RadioButtonGroup_PaddingLeftLabel_Form: 2.1875rem;
/* END "RadioButtonGroup.less" */

/* START "RangeSlider.less" */
/* ================================== */
/* CSS for control sap.m/RangeSlider  */
/* Fiori 3 theme                      */
/* ================================== */

/* overlap */
.sapMSliderHandle.sapMSliderHandleOverlap {
	border: 0.125rem solid darken(@sapUiFieldActiveBorderColor, 5);
}

.sapMRangeSlider.sapMSlider {

	.sapMSliderLabels {
		height: 1rem;

		.sapMSliderRangeLabel {
			width: 2rem;
			font-size: var(--sapFontSmallSize);
			color: var(--sapContent_LabelColor);
		}
	}

	.sapMSliderInner .sapMSliderHandle {
		background: fade(@sapUiButtonBackground, 25);
	}

	.sapMSliderInner:not(.sapMSliderInnerDisabled) .sapMSliderHandle {

		&:hover {
			background-color: transparent;
			border-color: var(--sapButton_Hover_BorderColor);
		}

		&:active {
			background: transparent;
			border-color: var(--sapButton_Active_BorderColor);
		}

		&.sapMSliderHandlePressed {
			background: transparent;
			border-color: var(--sapButton_Active_BorderColor);
		}
	}

	.sapMSliderInner:not(.sapMSliderInnerDisabled) .sapMSliderProgress:hover ~ .sapMSliderHandle,
	.sapMSliderHandle:hover {
		background-color: fade(@sapUiButtonHoverBackground, 25);
		border-color: var(--sapButton_Hover_BorderColor);
	}
}
/* END "RangeSlider.less" */

/* START "RatingIndicator.less" */
/* ====================================== */
/* CSS for control sap.m/RatingIndicator  */
/* Fiori 3 theme                          */
/* ====================================== */

.sapMRI {
	text-shadow: var(--sapContent_TextShadow);

	.sapMRIUnsel {
		color: var(--sapContent_UnratedColor);
	}

	.sapMRISel {
		color: var(--sapContent_RatedColor);
	}

	.sapMRIHov {
		color: darken(@sapUiContentRatedColor, 5);
	}
}

.sapMRI.sapMRIDisplayOnly {
	text-shadow: none;

	.sapMRIIconSel {
		color: var(--sapTextColor);
	}
	.sapMRIUnsel {
		color: var(--sapContent_UnratedColor);
	}
}

.sapMRIDisabled {
	text-shadow: none;
	opacity: 0.4;
}

/* Custom focus outline */
html.sap-desktop .sapMRI:focus:not(.sapMRIDisabled):not(.sapMRIDisplayOnly) {
	outline: var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);
	outline-offset: 0.0625rem;
}

.sapMRIIconSel,
.sapMRIIconUnsel,
.sapMRIIconHov,
.sapMRIIconReadOnly {
	font-size: 1.5rem;
}
/* END "RatingIndicator.less" */

/* START "ResponsivePopover.less" */
/* ======================================== */
/* CSS for control sap.m/ResponsivePopover  */
/* Fiori 3 theme                            */
/* ======================================== */

.sapMResponsivePopover.sapMDialog .sapMIBar.sapMPageHeader:before{
	border-top: none;
}

.sapMPopoverFooter .sapMTB .sapMBtn {
	min-width: 4rem;
}
/* END "ResponsivePopover.less" */

/* START "ScrollContainer.less" */
/* ====================================== */
/* CSS for control sap.m/ScrollContainer  */
/* Fiori 3 theme                          */
/* ====================================== */

html.sap-desktop:not(.sapUiNativeScrollbars) .sapMScrollContV::-webkit-scrollbar {
	width: 0.75rem;
	height: 100%;
}

html.sap-desktop:not(.sapUiNativeScrollbars) .sapMScrollContH::-webkit-scrollbar {
	width: 100%;
	height: 0.75rem;
}

html.sap-desktop:not(.sapUiNativeScrollbars) .sapMScrollContVH::-webkit-scrollbar {
	width: 0.75rem;
	height: 0.75rem;
}
/* END "ScrollContainer.less" */

/* START "SearchField.less" */
/* ================================== */
/* CSS for control sap.m/SearchField  */
/* Fiori 3 theme                      */
/* ================================== */

// ==========================================================================
// Variables overriding
// ==========================================================================

@_sap_m_SearchField_Height: 2.75rem;
@_sap_m_SearchField_ButtonSize: 2.125rem;
@_sap_m_SearchField_ButtonFontSize: 1rem;
@_sap_m_SearchField_Compact_FormPaddingLeft: 0.5rem;
@_sap_m_SearchField_ResetIcon: '\e03e';

.sapMSFF {
	border-radius: var(--sapField_BorderCornerRadius);
}

.sapMSFDisabled {
	opacity: 0.5;
}

/* custom buttons */
.sapMSFB:focus {
	outline: none;
}

.sapMBarChild > .sapMSFF > .sapMSFB {
	text-shadow: none;
}

.sapMFocus > .sapMSFF > .sapMSFB {
	color: var(--sapHighlightColor);
}

.sapMSFB:hover {
	background-color: var(--sapButton_Lite_Hover_Background);
}

.sapMSFF > .sapMSFB:not(.sapMSFBF):active,
.sapMSFF > .sapMSFB.sapMSFBA {
	background-color: var(--sapButton_Lite_Active_Background);
	color: var(--sapContent_ContrastIconColor);
}

.sapMSFB:first-of-type {
	margin-left: 0.5rem;
}

.sapUiSizeCompact {

	.sapMSFB:first-of-type {
		margin-left: 0;
	}
}
/* END "SearchField.less" */

/* START "SegmentedButton.less" */
/* ====================================== */
/* CSS for control sap.m/SegmentedButton  */
/* Fiori 3 theme                          */
/* ====================================== */

.sapMSegB {
	height: 2.75rem;
	vertical-align: top;
	position: relative;

	.sapMSegBBtn {

		.sapMSegBBtnInner {
			font-size: @sapMFontMediumSize;
			height: 2.25rem;
			line-height: 2.25rem;
			padding-left: 0.5625rem;
			padding-right: 0.5625rem;
			text-align: center;
			text-shadow: none;
			color: var(--sapButton_TextColor);
			border-top: 1px solid var(--sapButton_BorderColor);
			border-left: 1px solid var(--sapButton_BorderColor);
			border-bottom: 1px solid var(--sapButton_BorderColor);
			border-right: 1px solid transparent;
			background-color: var(--sapButton_Background);
		}

		&:not(.sapMSegBBtnMixed) .sapMImg {
			padding-left: 0.5625rem;
			padding-right: 0.5625rem;
		}
	}
}

.sapMSegBBtn:first-child .sapMSegBBtnInner {
	border-top-left-radius: 0.25rem;
	border-bottom-left-radius: 0.25rem;
}

.sapMSegBBtn:last-child .sapMSegBBtnInner {
	border-top-right-radius: 0.25rem;
	border-bottom-right-radius: 0.25rem;
}

html.sap-desktop .sapMSegBBtnFocusable:hover .sapMSegBBtnInner {
	background: var(--sapButton_Hover_Background);
}

/* Custom focus outline: */
html.sap-desktop {

	.sapMSegBBtnFocusable:focus .sapMSegBBtnInner {
		outline: 1px dotted;
		outline-offset: -3px;
		outline-color: var(--sapContent_FocusColor);
	}

	.sapMSegBBtnFocusable.sapMSegBBtnSel:focus .sapMSegBBtnInner {
		outline: 1px dotted;
		outline-offset: -3px;
		outline-color: var(--sapContent_ContrastFocusColor);
	}
}

.sapMSegB.sapMSegBIcons {

	.sapMSegBBtn:not(.sapMSegBBtnMixed) .sapMSegBBtnInner {
		padding: 0;
	}

	.sapMSegBBtn.sapMSegBBtnMixed .sapMImg {
		height: 2.125rem;
		width: auto;
		padding-right: 0.375rem;
	}

	.sapMSegBBtn.sapMSegBBtnMixed .sapUiIcon {
		padding-left: 0;
		padding-right: 0.375rem;
		width: 1rem;
	}
}

.sapMSegBBtn.sapMSegBBtnFocusable:active:hover {

	.sapMSegBBtnInner {
		background: var(--sapButton_Selected_Background);
		color: var(--sapButton_Selected_TextColor);
		border-color: var(--sapButton_Selected_BorderColor);
	}

	.sapUiIcon {
		color: var(--sapButton_Selected_TextColor);
	}
}

.sapMSegBBtn.sapMSegBBtnSel {

	.sapMSegBBtnInner {
		background: var(--sapButton_Selected_Background);
		color: var(--sapButton_Selected_TextColor);
		border-color: var(--sapButton_Selected_BorderColor);
	}

	.sapUiIcon {
		color: var(--sapButton_Selected_TextColor);
	}
}

.sapMSegBBtn.sapMSegBBtnSel:hover {

	.sapMSegBBtnInner {
		border-color: var(--sapButton_Selected_Hover_BorderColor);
	}
}

.sapMSegBBtnFocusable.sapMBtnActive {

	.sapMSegBBtnInner {
		background: var(--sapButton_Selected_Background);
		color: var(--sapButton_Selected_TextColor);
	}

	.sapUiIcon {
		color: var(--sapButton_Selected_TextColor);
	}
}

html.sap-desktop .sapMSegBBtn.sapMSegBBtnFocusable.sapMSegBBtnSel:hover .sapMSegBBtnInner,
html.sap-desktop .sapMSegBBtnFocusable.sapMBtnActive:hover .sapMSegBBtnInner {
	background: var(--sapButton_Selected_Hover_Background);
}

.sapMSegBBtn.sapMSegBBtnFocusable.sapMSegBBtnSel {

	.sapMSegBBtnInner {
		border-right: 1px solid var(--sapButton_Selected_BorderColor);
	}

	.sapMSegBBtnInner:hover {
		border-right: 1px solid var(--sapButton_Selected_Hover_BorderColor);
	}

	/* Hide next button left border */
	+ .sapMSegBBtn .sapMSegBBtnInner {
		border-left: 1px solid transparent;
	}
}

.sapMSegB img {
	height: 2.125rem;
	width: auto;
	max-height: 2.125rem;
	vertical-align: top;
}

.sapMSegBBtn .sapUiIcon {
	width: auto;
	font-size: 1rem;
	line-height: 2.125rem;
	margin-right: 0;
	color: var(--sapButton_IconColor);
	vertical-align: top;
	text-align: center;
}

.sapMSegBBtn.sapMSegBBtnMixed .sapUiIcon {
	padding-right: 0.375rem;
}

.sapMSegBBtn .sapMBtnIcon::before {
	width: 1rem;
	text-align: center;
	display: inline-block;
}

.sapMSB .sapMSBInner .sapMSBText:not(.sapMSBTextIE) .sapMBtnInner {
	margin-right: 2.2rem;
}

.sapMSegBIcons:not(.sapMSegBBtnMixed) {

	.sapMImg,
	.sapUiIcon {
		padding-left: 0.5625rem;
		padding-right: 0.5625rem;
	}
}
/* Compact size */
.sapUiSizeCompact {

	.sapMSegBBtn .sapMSegBBtnInner {
		height: 1.625rem;
		line-height: 1.5rem;
		padding-left: 0.4375rem;
		padding-right: 0.4375rem;
	}

	.sapMSegBBtn:first-child .sapMSegBBtnInner {
		border-top-left-radius: 0.2rem;
		border-bottom-left-radius: 0.2rem;
	}

	.sapMSegBBtn:last-child .sapMSegBBtnInner {
		border-top-right-radius: 0.2rem;
		border-bottom-right-radius: 0.2rem;
	}

	.sapMSegB img {
		line-height: 1.5rem;
		height: 1.5rem;
		width: auto;
	}

	.sapMSegBBtn .sapUiIcon {
		font-size: 1rem;
		line-height: 1.5rem;
		width: 1.0rem;
		vertical-align: top;
	}
	.sapMSegB {

		.sapMBtnIconLeft {
			margin-left: 0;
		}
	}

	.sapMSegBIcons:not(.sapMSegBBtnMixed) {

		.sapMImg,
		.sapUiIcon {
			padding-left: 0.4375rem;
			padding-right: 0.4375rem;
		}
	}
	.sapMSegBIcons {

		.sapMSegBBtn.sapMSegBBtnMixed {

			.sapUiIcon,
			.sapMImg {
				padding-left: 0;
				padding-right: 0.375rem;
				margin: 0;
			}

			.sapMImg {
				height: 1.5rem;
				width: auto; /*1.5rem; */
			}
		}
	}
}

.sapMSegBBtn.sapMSegBtnLastVisibleButton .sapMSegBBtnInner {
	border-right: 1px solid var(--sapButton_BorderColor);
	border-top-right-radius: 0.2rem;
	border-bottom-right-radius: 0.2rem;
}
/* END "SegmentedButton.less" */

/* START "Select.less" */
/* ============================= */
/* CSS for control sap.m/Select  */
/* Fiori 3 theme                 */
/* ============================= */

/* IconOnly */

.sapMSlt.sapMSltIconOnly:not(.sapMSltDisabled) {
	border-color: var(--sapButton_Lite_BorderColor);
	background: var(--sapButton_Lite_Background);
	border-radius: 0.2rem;
}

/* IconOnly Hover */

.sapMSltIconOnly.sapMSltHoverable:hover:not(.sapMSltState) {
	background: var(--sapButton_Lite_Hover_Background);

	&.sapMSltWithIcon {
		border: 0.0625rem solid var(--sapButton_Lite_Hover_BorderColor);
	}
}

/*IconOnly Pressed */
.sapMSltPressed.sapMSltIconOnly:not(.sapMSltDisabled) {
	background: @sapUiToggleButtonPressedBackground;
	border: 0.0625rem solid @sapUiToggleButtonPressedBorderColor;
}

.sapMSlt:not(.sapMSltIconOnly) {
	border-radius: 0.125rem;
}

.sapMSlt {
	height: 2.25rem;
}

.sapMSltArrow {
	line-height: 2.25rem;
}

.sapMSltPressed > .sapMSltArrow::before {
	color: var(--sapButton_Active_TextColor);
}

html.sap-desktop .sapMSlt.sapMSltFocused:not(.sapMSltExpanded):not(.sapMSltDisabled) {

	&::before {
		pointer-events: none;
		content: '';
		position: absolute;
		left: 0;
		top: 0;
		right: 0;
		bottom: 0;
		z-index: 1;
		outline: 1px dotted var(--sapContent_FocusColor);
	}
}

html.sap-desktop .sapMSlt.sapMSltFocused:not(.sapMSltExpanded):not(.sapMSltDisabled):not(.sapMSltState)::before {
	outline-offset: -2px;
}

html.sap-desktop .sapMSlt.sapMSltFocused:not(.sapMSltExpanded):not(.sapMSltDisabled).sapMSltState::before {
	outline-offset: -2px;
}

html.sap-desktop .sapMSltIconOnly.focus:not(.sapMSltExpanded):not(.sapMSltDisabled).sapMSltPressed {
	outline-color: var(--sapContent_ContrastFocusColor);
}

.sapMSltHoverable:not(.sapMSltState):not(.sapMSltIconOnly):hover {
	border-color: var(--sapField_Hover_BorderColor);
	background: var(--sapField_Hover_Background);
}

/* pressed and hover */

.sapMSltIconOnly.sapMSltPressed.sapMSltHoverable:not(.sapMSltState):hover {
	background: @sapUiToggleButtonPressedHoverBackground;
	border-color: var(--sapField_Active_BorderColor);
}

/* value state */

.sapMSltState {
	border-width: 2px;
}

/* disabled */

.sapMSltDisabled {
	opacity: 0.5;
}

div.sapMSltPicker .sapMSltPickerValueState {
	box-shadow: inset 0 -0.0625rem @_sap_m_Dialog_HeaderShadowColor;
}
/* END "Select.less" */

/* START "SelectDialog.less" */
/* =================================== */
/* CSS for control sap.m/SelectDialog  */
/* Fiori 3 theme                       */
/* =================================== */

.sapMSelectDialog.sapUiResponsivePadding--content .sapMDialogScrollCont {

	&.sapUi-Std-PaddingS {
		padding-left: 0rem !important;
		padding-right: 0rem !important;
	}

	&.sapUi-Std-PaddingM,
	&.sapUi-Std-PaddingL {
		padding-left: 1rem !important;
		padding-right: 1rem !important;
	}

	&.sapUi-Std-PaddingXL {
		padding-left: 2rem !important;
		padding-right: 2rem !important;
	}
}
/* END "SelectDialog.less" */

/* START "SelectList.less" */
/* ================================= */
/* CSS for control sap.m/SelectList  */
/* Fiori 3 theme                     */
/* ================================= */

@_sap_m_SelectListItem_Height: 2.5rem;
@_sap_m_SelectListItem_CompactHeight: 2rem;
@_sap_m_SelectListItemBelizeFocus_Height: 0.25rem; /* 2 borders * 0.0625rem + 2 offsets (top and bottom) * 0.0625rem */

/* selected */
.sapMSelectListItemBaseSelected {
	background: var(--sapList_SelectionBackgroundColor);
	border-bottom: 0.0625rem solid var(--sapSelectedColor);
}

.sapMSltPicker-CTX .sapMSelectListItemBaseSelected,
.sapMComboBoxBasePicker-CTX .sapMSelectListItemBaseSelected {
	outline: 0.0625rem dotted var(--sapContent_FocusColor);
	outline-offset: -0.125rem;
}

/* pressed */
html.sap-desktop .sapMSelectListItemBase.sapMSelectListItemBasePressed:focus {
	outline: 0.0625rem dotted var(--sapContent_ContrastFocusColor);
}

.sapMSelectListItemBase.sapMSelectListItemBasePressed .sapMSelectListItemIcon {
	color: var(--sapContent_ContrastIconColor);
}

/* disabled */
.sapMSelectListItemBaseDisabled {
	opacity: 0.5;
}

/* focus */
html.sap-desktop .sapMSelectListItemBase:focus {
	outline: 0.0625rem dotted var(--sapContent_FocusColor);
	outline-offset: -0.125rem;
}
/* END "SelectList.less" */

/* START "Shell.less" */
/* ============================ */
/* CSS for control sap.m/Shell  */
/* Fiori 3 theme                */
/* ============================ */

/* background color class for Shell header */
.sapMShellBackgroundColorOnlyIfDefaultMixin() when not (@sapUiGlobalBackgroundImage = '') {
	background-color: @sapUiShellBackgroundImage; /* custom BG image... just hide the background */
}

.sapMShellBackgroundColorOnlyIfDefaultMixin() when (@sapUiGlobalBackgroundImage = '') {
	background-color: @sapUiShellBackgroundGradient; /* default BG image - display the default background color */
}

.sapMShellBackgroundColorOnlyIfDefault {
	.sapMShellBackgroundColorOnlyIfDefaultMixin;
}

html.sap-desktop .sapMShellCentralBox {
	box-shadow: none;
}

.sapMShellBrandingBar {
	background-color: transparent;
}

.sapMShellGlobalOuterBackground {
	background: var(--sapShell_Background);
}

html.sap-desktop {

	.sapMShellLogo,
	.sapMShellAppWidthLimited .sapMShellLogo {
		margin: 1rem 1rem 0 0;
	}
}
/* END "Shell.less" */

/* START "SinglePlanningCalendarGrid.less" */
/* ================================================= */
/* CSS for control sap.m/SinglePlanningCalendarGrid  */
/* Fiori 3 theme                                     */
/* ================================================= */

.sapUiSizeCompact .sapMSinglePCGrid {

	& .sapUiCalItem {
		text-align: left;
	}

	& .sapUiCalDayName {
		text-align: right;
	}
}

.sapMSinglePC .sapUiCalendarAppCont {
	border-left: 0.0625rem solid darken(@sapUiListBorderColor, 15);
	border-radius: 0 0.125rem 0.125rem 0.125rem;
}

.sapMSinglePC {

	.sapMSinglePCRow,
	.sapMSinglePCBlockersColumn {
		border-color: var(--sapList_BorderColor);
	}

	.sapMSinglePCColumnToday .sapMSinglePCRow::before {
		border-color: var(--sapLegend_CurrentDateTime);
	}

	.sapMSinglePCColumnHeader .sapUiCalItem.sapUiCalItemNow {
		border-color: var(--sapLegend_CurrentDateTime);
		border-radius: 0.25rem;
	}

	.sapMSinglePCNowMarker {
		color: var(--sapLegend_CurrentDateTime);
	}

	.sapMSinglePCColumnWeekend,
	.sapMSinglePCNonWorkingRow,
	.sapMSinglePCBlockersRow,
	.sapMSinglePCRowHeaders,
	.sapMSinglePCNonWorkingPeriod {
		background-color: var(--sapList_AlternatingBackground);
	}

	.sapMPCHeadNavToolbar.sapMTB-Transparent-CTX.sapMTB {
		background-color: var(--sapList_Background);
	}

	.sapMSinglePCAppointmentWrap.sapUiCalendarRowApps {

		&:focus {

			.sapUiCalendarAppSel > .sapUiCalendarAppCont::after {
				border: 0.0625rem dotted var(--sapContent_ContrastFocusColor);
			}
		}
	}

	.sapUiCalItem:focus {
		outline: none;
	}

	.sapMSinglePCColumnHeader {

		.sapUiCalItem.sapUiCalItemNow {

			.sapUiCalItemText {
				border: 0.0625rem solid var(--sapList_Background);
			}

			.sapUiCalSpecialDate {
				position: absolute;
				left: 0;
				bottom: 0;
				height: 0.28125rem;
			}
		}

		.sapUiCalItem .sapUiCalSpecialDate {
			height: 0.25rem;
		}

		.sapUiCalItem.sapUiCalItemNow.sapUiCalItemSel .sapUiCalItemText {
			border: 0.0625rem solid var(--sapList_Background);
		}
	}
}

.sapUiCalendarRowVisFilled .sapMSinglePCAppointmentWrap {

	.sapUiCalendarApp,
	.sapUiCalendarApp:hover:not(:active) {
		background-color: transparent;
	}
}

.sapUiSizeCompact .sapMSinglePC {

	.sapMSinglePCColumnHeader {

		.sapUiCalItem.sapUiCalItemNow {

			&.sapUiCalItemSel {
				background-color: var(--sapActiveColor);
			}

			.sapUiCalItemText,
			.sapUiCalItemSel.sapUiItemText {
				box-shadow: none;
				border: none;
			}
		}
	}

	.sapMSinglePCColumnHeader {

		.sapUiCalItem.sapUiCalItemNow:focus {
			outline: 0.0625rem solid white;
			box-shadow: inset white;
		}
	}
}

.sapUiSizeCompact .sapMSinglePC {

	.sapMSinglePCColumnHeader {

		.sapUiCalItem.sapUiCalItemNow {
			outline: 0.0625rem solid white;
			box-shadow: inset white;

			&.sapUiCalItemSel {
				background-color: var(--sapActiveColor);
				border: 0.125rem solid var(--sapLegend_CurrentDateTime);
			}

			&.sapUiCalItemSel:hover {
				background-color: var(--sapContent_Selected_Hover_Background);
			}

			&.sapUiCalItemSel .sapUiCalItemText,
			.sapUiCalItemText {
				box-shadow: none;
				border: transparent;
				line-height: 1.5rem;
			}
		}

		.sapUiCalItem.sapUiCalItemSel:not(.sapUiCalItemSelBetween) > .sapUiCalItemText,
		.sapUiCalItem.sapUiCalItemSel:not(.sapUiCalItemNow):not(.sapUiCalItemSelBetween):focus > .sapUiCalItemText {
			border: transparent;
		}

		.sapUiCalItem.sapUiCalItemSel .sapUiCalItemText,
		.sapUiCalItemText {
			line-height: 1.5rem;
		}

		.sapUiCalItem:focus > .sapUiCalItemText {
			outline: none;
		}

		.sapUiCalItem {

			.sapUiCalItemText,
			.sapUiCalDayName {
				height: 1.4rem;
				padding-left: 0.125rem;
			}

			&.sapUiCalItemNow .sapUiCalDayName,
			.sapUiCalItemText {
				line-height: 1.5rem;
			}

			.sapUiCalDayName {
				line-height: 1.5rem;
				padding-right: 0.125rem;
			}
		}
	}
}
/* END "SinglePlanningCalendarGrid.less" */

/* START "SinglePlanningCalendarMonthGrid.less" */
/* ====================================================== */
/* CSS for control sap.m/SinglePlanningCalendarMonthGrid  */
/* Fiori 3 theme                                          */
/* ====================================================== */

.calendarSpecialDayTypeColorMixIn(@class, @color) {
	.sapMSPCMonthGrid {
		.@{class} .specialDateIndicator {
			background-color: @color;
		}
	}
}

.calendarSpecialDayTypeColorMixIn(sapUiCalendarSpecialDayType01, @sapLegendColor1);
.calendarSpecialDayTypeColorMixIn(sapUiCalendarSpecialDayType02, @sapLegendColor2);
.calendarSpecialDayTypeColorMixIn(sapUiCalendarSpecialDayType03, @sapLegendColor3);
.calendarSpecialDayTypeColorMixIn(sapUiCalendarSpecialDayType04, @sapLegendColor4);
.calendarSpecialDayTypeColorMixIn(sapUiCalendarSpecialDayType05, @sapLegendColor5);
.calendarSpecialDayTypeColorMixIn(sapUiCalendarSpecialDayType06, @sapLegendColor6);
.calendarSpecialDayTypeColorMixIn(sapUiCalendarSpecialDayType07, @sapLegendColor7);
.calendarSpecialDayTypeColorMixIn(sapUiCalendarSpecialDayType08, @sapLegendColor8);
.calendarSpecialDayTypeColorMixIn(sapUiCalendarSpecialDayType09, @sapLegendColor9);
.calendarSpecialDayTypeColorMixIn(sapUiCalendarSpecialDayType10, @sapLegendColor10);
.calendarSpecialDayTypeColorMixIn(sapUiCalendarSpecialDayType11, @sapLegendColor11);
.calendarSpecialDayTypeColorMixIn(sapUiCalendarSpecialDayType12, @sapLegendColor12);
.calendarSpecialDayTypeColorMixIn(sapUiCalendarSpecialDayType13, @sapLegendColor13);
.calendarSpecialDayTypeColorMixIn(sapUiCalendarSpecialDayType14, @sapLegendColor14);
.calendarSpecialDayTypeColorMixIn(sapUiCalendarSpecialDayType15, @sapLegendColor15);
.calendarSpecialDayTypeColorMixIn(sapUiCalendarSpecialDayType16, @sapLegendColor16);
.calendarSpecialDayTypeColorMixIn(sapUiCalendarSpecialDayType17, @sapLegendColor17);
.calendarSpecialDayTypeColorMixIn(sapUiCalendarSpecialDayType18, @sapLegendColor18);
.calendarSpecialDayTypeColorMixIn(sapUiCalendarSpecialDayType19, @sapLegendColor19);
.calendarSpecialDayTypeColorMixIn(sapUiCalendarSpecialDayType20, @sapLegendColor20);
/* END "SinglePlanningCalendarMonthGrid.less" */

/* START "Slider.less" */
/* ============================= */
/* CSS for control sap.m/Slider  */
/* Fiori 3 theme                 */
/* ============================= */

@_sap_m_Slider_Height: 2.75rem;
@_sap_m_Slider_Progress: .25rem;

/* slider */
.sapMSliderInner {
	background: var(--sapField_BorderColor);
}

.sapMSliderProgress {
	background: var(--sapActiveColor);
}

.sapMSliderInner:not(.sapMSliderInnerDisabled) .sapMSliderProgress:hover ~ .sapMSliderHandle,
.sapMSliderHandle:hover {
	background: var(--sapButton_Hover_Background);
	border-color: var(--sapButton_Hover_BorderColor);
}

/* slider handle */
.sapMSliderInner .sapMSliderHandle {
	background: var(--sapButton_Background);
	border: solid 0.125rem var(--sapField_BorderColor);
	width: 1.875rem;
	height: 1.875rem;
	margin-left: -0.9375rem;
	top: -0.8125rem;
}

.sapMSliderInner:not(.sapMSliderInnerDisabled) .sapMSliderHandle {

	&:hover {
		background: var(--sapButton_Hover_Background);
		border-color: var(--sapButton_Hover_BorderColor);
	}

	&:active {
		background: var(--sapButton_Active_Background);
		border-color: var(--sapButton_Active_BorderColor);
	}
}

.sapMSliderTickLabel .sapMSliderLabel {
	padding-top: 0.4375rem;
	height: 1rem;
	width: 2rem;
	left: -1rem;
	font-size: var(--sapFontSmallSize);
	color: var(--sapContent_LabelColor);
}

.sapMSliderTick {
	margin: 0.375rem 0 0 -0.0625rem;
}

.sapMSliderLabels {
	height: 1rem;

	.sapMSliderRangeLabel {
		width: 2rem;
		font-size: var(--sapFontSmallSize);
		color: var(--sapContent_LabelColor);
	}
}

/* disabled */
.sapMSliderDisabled {
	opacity: 0.5;
}

/* pressed */
.sapMSliderPressed:not(.sapMSliderInnerDisabled) > .sapMSliderHandle,
.sapMSlider .sapMSliderInner > .sapMSliderHandle.sapMSliderHandlePressed {
	background-color: var(--sapButton_Active_Background);
	border: 0.125rem solid var(--sapButton_Active_BorderColor);
}

.sapUiSizeCompact {

	.sapMSliderHandle {
		width: 1.5rem;
		height: 1.5rem;
		margin-left: -0.75rem;
		top: -0.625rem;
	}

	.sapMSliderTickLabel .sapMSliderLabel {
		padding-top: 0.375rem;
	}
}

.sapMSliderTick[data-ui5-active-tickmark='true'] {
	border-left: 0.0625rem solid var(--sapActiveColor);
}
/* END "Slider.less" */

/* START "SliderTooltip.less" */
/* ==================================== */
/* CSS for control sap.m/SliderTooltip  */
/* Fiori 3 theme                        */
/* ==================================== */

/* Slider Tooltip styles          */

.sapMSliderTooltip {
	background: var(--sapField_Background);
	border-radius: var(--sapElement_BorderCornerRadius);
	border: 1px solid var(--sapField_BorderColor);
	box-shadow: none;
	height: 1.375rem;
	min-width: 2rem;
	padding: 0.25rem;
	font-size: var(--sapFontSmallSize);
	color: var(--sapContent_LabelColor);
}

.sapMSliderTooltipInput {
	font-size: @sapMFontMediumSize;
	color: var(--sapField_TextColor);
}

.sapMSliderTooltipErrorState {
	background: var(--sapField_InvalidBackground);
	border-color: var(--sapField_InvalidColor);
}

.sapMSliderTooltipErrorState .sapMSliderTooltipInput {
	background: var(--sapField_InvalidBackground);
}

.sapMSliderTooltip.sapMSliderTooltipNonEditableWrapper {
	border-radius: 0.25rem;
	height: 0.875rem;
	padding: 0.25rem;
	font-size: var(--sapFontSmallSize);
	color: var(--sapContent_LabelColor);
}
/* END "SliderTooltip.less" */

/* START "SlideTile.less" */
/* ================================ */
/* CSS for control sap.m/SlideTile  */
/* Fiori 3 theme                    */
/* ================================ */

.sapMST:active .sapMSTFocusDiv {
	border: 1px solid var(--sapTile_Background);
}

.sapMST.sapMSTScopeActions.sapMSTDarkBackground .sapMSTMoreIcon {

	.sapMBtnIcon {
		color: var(--sapContent_ContrastTextColor);
	}
}

/* This part is used to achieve dotted white black interlace border */
.sapMST:focus .sapMSTFocusDiv::after,
.sapMST:active .sapMSTFocusDiv::after {
	content: '';
	position: absolute;
	top: 0;
	bottom: 0;
	left: 0;
	right: 0;
	border-radius: 0.25rem;
	margin: -1px;
	border: 1px dotted var(--sapContent_FocusColor);
}

/* Bulleted indicator of multiple tiles */
.sapMSTBulleted .sapMSTIndicator {
	background-color: @sapUiContentNonInteractiveIconColor;
	box-shadow: 0 0 0.125rem var(--sapContent_ShadowColor);
}

.sapMSTBulleted .sapMSTIndicator.sapMSTActive {
	background-color: @sapUiContentContrastIconColor;
	box-shadow: 0 0 0.063rem var(--sapContent_ShadowColor);
}

.sapMST .sapMSTIconDisplayArea {
	background-color: var(--sapBlockLayer_Background);
}

.sapMST.sapMSTIconPressed .sapMSTIconClickTapArea:hover ~.sapMSTIconDisplayArea {
	background-color: var(--sapBrandColor);
}

.sapMST .sapMSTIconNestedArea {
	text-shadow: 0 1px var(--sapButton_Emphasized_TextShadow);
}

.sapMST .sapMGT:active .sapMGTFocusDiv,
.sapMST .sapMGT:active .sapMGTFocusDiv::after {
	border: none;
}
/* END "SlideTile.less" */

/* START "SplitButton.less" */
/* ================================== */
/* CSS for control sap.m/SplitButton  */
/* Fiori 3 theme                      */
/* ================================== */

.sapMIBar-CTX.sapMFooter-CTX .sapMSB.sapMSBEmphasized:focus .sapMSBInner::after,
.sapMSB.sapMSBEmphasized:focus .sapMSBInner::after {
	border-color: var(--sapContent_ContrastFocusColor);
}

.sapMSB .sapMSBArrow:not(.sapMBtnDisabled) .sapMBtnTransparent:not(.sapMToggleBtnPressed),
.sapContrast.sapMIBar-CTX .sapMSB .sapMSBArrow:not(.sapMBtnDisabled) .sapMBtnTransparent:not(.sapMToggleBtnPressed),
.sapContrast .sapMIBar-CTX .sapMSB .sapMSBArrow:not(.sapMBtnDisabled) .sapMBtnTransparent:not(.sapMToggleBtnPressed) {
	border-left-color: var(--sapButton_BorderColor);
}

.sapMSB .sapMSBArrow:not(.sapMBtnDisabled) .sapMBtnActive.sapMBtnTransparent:not(.sapMToggleBtnPressed),
.sapContrast.sapMIBar-CTX .sapMSB .sapMSBArrow:not(.sapMBtnDisabled) .sapMBtnActive.sapMBtnTransparent:not(.sapMToggleBtnPressed),
.sapContrast .sapMIBar-CTX .sapMSB .sapMSBArrow:not(.sapMBtnDisabled) .sapMBtnActive.sapMBtnTransparent:not(.sapMToggleBtnPressed) {
	border-left-color: var(--sapButton_Lite_Active_BorderColor);
}

.sapMMenuBtn {

	.sapMSBArrow.sapMBtn:hover > .sapMBtnHoverable.sapMBtnEmphasized,
	.sapMSBArrow span.sapMBtnInner.sapMBtnEmphasized {
		border-left-color: var(--sapButton_Background);
	}
}

.sapMSB .sapMSBArrow.sapMBtn:hover > .sapMBtnHoverable.sapMBtnEmphasized:not(.sapMBtnActive):not(.sapMToggleBtnPressed) {
	border-left-color: var(--sapButton_Background);
}

.sapMMenuBtn.sapMSBArrow.sapMMenuBtnSplit .sapMSBActive:not(.sapMBtnDisabled) > span.sapMBtnInner.sapMBtnEmphasized {
	border-left-color: var(--sapButton_Background);
}

/* ie */
.sapMSBTextIE.sapMSBText {
	padding-right: 2.25rem;
}
/* END "SplitButton.less" */

/* START "StandardListItem.less" */
/* ======================================= */
/* CSS for control sap.m/StandardListItem  */
/* Fiori 3 theme                           */
/* ======================================= */

@_sap_m_StandardListItem_TextShadowColor: none;
@_sap_m_StandardListItem_SelectedLabelColor: var(--sapContent_LabelColor);

.sapMSLIInfo {
	text-shadow: @_sap_m_StandardListItem_TextShadowColor;
}

.sapMSLI {
	height: 2.75rem;
}

.sapMSLIImgIcon {
	height: 2.75rem;
	width: 2.75rem;
	line-height: 2.75rem;
	font-size: 1.25rem;
}

.sapMSLIImgNoInset,
.sapMSLIImg {
	border-radius: 0.25rem;
}

/* Compact Size */
.sapUiSizeCompact .sapMSLIImgIcon {
	height: 2rem;
}

/* END "StandardListItem.less" */

/* START "StandardTile.less" */
/* =================================== */
/* CSS for control sap.m/StandardTile  */
/* Fiori 3 theme                       */
/* =================================== */

.sapMStdTileIconDiv {
	color: var(--sapHighlightColor);
}

.sapMStdIconCreate {
	opacity: .3;
}

.sapMStdTileMonitorType {
	background-color: darken(@sapUiTileBackground, 5);
}

.sapMTCEditable .sapMStdTileMonitorType {
	background-color: fade(darken(@sapUiTileBackground, 5), 50);
}

.sapMStdTileMonitorType .sapMStdTileTitle {
	color: var(--sapTile_TitleTextColor);
}

.sapMTileActive-CTX .sapMStdTileMonitorType {
	background-color: transparent;
}
/* END "StandardTile.less" */

/* START "Switch.less" */
/* ============================= */
/* CSS for control sap.m/Switch  */
/* Fiori 3 theme                 */
/* ============================= */

@_sap_m_Switch_OffBackground: lighten(@sapUiButtonBackground, 3);
@_sap_m_Switch_OffBorderColor: var(--sapButton_BorderColor);

/* Switch container */
.sapMSwtCont {
	overflow: hidden;
	/* in order to have a touchable area of 2.75rem */
	padding-top: 0.6875rem;
	padding-bottom: 0.6875rem;
	padding-left: 0.125rem;
	width: 4.125rem;
}

/* focus */
html.sap-desktop {

	.sapMSwtCont:focus > .sapMSwt::before {
		content: ' ';
		position: absolute;
		display: block;
		top: -0.375rem;
		left: -0.125rem;
		bottom: -0.375rem;
		right: -0.125rem;
		outline: 1px dotted var(--sapContent_FocusColor);
	}

	.sapUiSizeCompact {

		.sapMSwtCont:focus > .sapMSwt:not(.sapMSwtNoLabel)::before {
			top: -0.25rem;
			bottom: -0.25rem;
		}

		.sapMSwtCont:focus > .sapMSwt.sapMSwtNoLabel::before {
			top: -0.375rem;
			bottom: -0.375rem;
		}
	}
}

/* Switch */
.sapMSwt {
	box-sizing: border-box;
	width: 3.875rem;
	height: 1.375rem;
	overflow: visible;
	border: var(--sapButton_BorderWidth) solid;
	border-top-left-radius: 0.75rem;
	border-top-right-radius: 0.75rem;
	border-bottom-right-radius: 0.75rem;
	border-bottom-left-radius: 0.75rem;

	&.sapMSwtNoLabel {
		width: 3.25rem;
		height: 1.25rem;
		outline-offset: -8px; /* ON state handle movement limit correction in pixels for no-label switches, because of reduced width */

		&.sapMSwtOn .sapMSwtInner {
			left: -0.5rem;
		}
	}
}

/* background */

.sapMSwtOff:not(.sapMSwtAcceptReject) {
	background: @_sap_m_Switch_OffBackground;
	border-color: var(--sapContent_ForegroundBorderColor);
}

.sapMSwt.sapMSwtOff.sapMSwtHoverable:not(.sapMSwtAcceptReject):hover {
	border-color: var(--sapContent_ForegroundBorderColor);
}

/* disabled */

.sapMSwtDisabled {
	opacity: var(--sapContent_DisabledOpacity);
}

/* Text */
.sapMSwtText {
	line-height: 1.25rem;
	width: 1.75rem;

	&.sapMSwtTextOn {
		margin: 0 0 0 0.125rem;
		color: var(--sapButton_Track_Selected_TextColor);
	}

	&.sapMSwtTextOff {
		margin: 0 0.125rem 0 0;
		color: var(--sapButton_Track_TextColor);
		left: 3.8rem;
	}

	.sapMSwtLabel {
		height: 1.25rem;
		padding: 0;
	}
}

/* Switch handler */
.sapMSwtOn .sapMSwtHandle,
.sapMSwtOff .sapMSwtHandle {
	height: 1.875rem;
	width: 1.875rem;
	border-top-left-radius: 1rem;
	border-top-right-radius: 1rem;
	border-bottom-right-radius: 1rem;
	border-bottom-left-radius: 1rem;
	border: var(--sapButton_BorderWidth) solid;
	left: 1.9375rem;
}

/* on */
.sapMSwt.sapMSwtOn:not(.sapMSwtAcceptReject) {
	background: var(--sapButton_Track_Selected_Background);
	border-color: var(--sapButton_Selected_BorderColor);

	.sapMSwtHandle {
		box-sizing: border-box;
		background: var(--sapButton_Selected_Background);
		border-color: var(--sapButton_Selected_BorderColor);
	}

	&.sapMSwtHoverable:not(.sapMSwtAcceptReject):hover {
		background: var(--sapButton_Track_Selected_Background);
		border-color: var(--sapButton_Selected_Hover_BorderColor);

		.sapMSwtHandle {
			background: var(--sapButton_Selected_Hover_Background);
			border-color: var(--sapButton_Selected_Hover_BorderColor);
		}
	}
}

/* off */
.sapMSwt.sapMSwtOff:not(.sapMSwtAcceptReject) {
	background: var(--sapButton_Track_Background);
	border-color: var(--sapContent_ForegroundBorderColor);

	.sapMSwtHandle {
		background: var(--sapButton_Background);
		border-color: var(--sapContent_ForegroundBorderColor);
	}

	&.sapMSwtHoverable:not(.sapMSwtAcceptReject):hover {
		border-color: var(--sapButton_Hover_BorderColor);

		.sapMSwtHandle {
			background: var(--sapButton_Hover_Background);
			border-color: var(--sapButton_Hover_BorderColor);
		}
	}
}

/* Switch type "AcceptReject" */

/* Switch */
.sapMSwtAcceptReject.sapMSwt {
	background: @_sap_m_Switch_OffBackground;

	/* on */
	&.sapMSwtOn {
		background: var(--sapSuccessBackground);
		border-color: var(--sapSuccessBorderColor);

		.sapMSwtHandle {
			background: var(--sapButton_Background);
			border-color: var(--sapSuccessBorderColor);
		}

		&.sapMSwtHoverable:hover {

			.sapMSwtHandle {
				background: var(--sapSuccessBackground);
			}
		}
	}

	/* off */
	&.sapMSwtOff {
		background: var(--sapErrorBackground);
		border-color: var(--sapErrorBorderColor);

		.sapMSwtHandle {
			background: var(--sapButton_Background);
			border-color: var(--sapErrorBorderColor);
		}

		&.sapMSwtHoverable:hover {

			.sapMSwtHandle {
				background: var(--sapErrorBackground);
			}
		}
	}
}

/* Switch handler */
.sapMSwt.sapMSwtAcceptReject.sapMSwtOff.sapMSwtHoverable:hover {
	background: var(--sapErrorBackground);
}

.sapMSwt.sapMSwtAcceptReject.sapMSwtOn.sapMSwtHoverable:hover {
	background: var(--sapSuccessBackground);
}

.sapMSwt.sapMSwtAcceptReject.sapMSwtOn .sapMSwtLabel {
	color: var(--sapPositiveElementColor);
	font-size: 0.75rem;
}

.sapMSwt.sapMSwtAcceptReject.sapMSwtOff .sapMSwtLabel {
	color: var(--sapNegativeElementColor);
	font-size: 0.75rem;
}

/* Compact mode */
.sapUiSizeCompact {

	.sapMSwtCont {
		width: 3.75rem;
		/* in order to have a touchable area of 2rem */
		padding-top: 0.3125rem;
		padding-bottom: 0.3125rem;

		.sapMSwt {
			width: 3.5rem;
			height: 1.375rem;

			&.sapMSwtNoLabel {
				width: 2.5rem;
				height: 1rem;
				margin-top: 0.0625rem;
				margin-bottom: 0.0625rem;
				outline-offset: -14px; /* ON state handle movement limit correction in pixels for no-label switches, because of reduced width */

				&.sapMSwtOn .sapMSwtInner {
					left: -0.88rem;
				}
			}

			.sapMSwtHandle {
				height: 1.625rem;
				width: 1.625rem;
				left: 1.88rem;
			}

			.sapMSwtText {
				line-height: 1.25rem;

				&.sapMSwtTextOff {
					left: 3.5rem;
				}

				.sapMSwtLabel {
					width: 1.75rem;
				}
			}

			&.sapMSwtOn .sapMSwtText.sapMSwtTextOff {
				left: 3.75rem;
			}

			&.sapMSwtOff .sapMSwtText.sapMSwtTextOn {
				left: -0.125rem;
			}
		}
	}
}
/* END "Switch.less" */

/* START "Table.less" */
/* ============================ */
/* CSS for control sap.m/Table  */
/* Fiori 3 theme                */
/* ============================ */

@_sap_m_Table_SelNavColWidth: 2.75rem;

.sapMListBGTransparent .sapMListTblHeader,
.sapMListBGTransparent .sapMListTblFooter {
	background-color: fade(@sapUiListBackground, 0%);
}

.sapMListBGTranslucent .sapMListTblHeader,
.sapMListBGTranslucent .sapMListTblFooter {
	background-color: var(--sapList_Background);
}

.sapMListBGSolid .sapMListTblHeader,
.sapMListBGSolid .sapMListTblFooter {
	background-color: var(--sapList_Background);
}

/* make the focus visible on all sides */
.sapMSticky .sapMLIBShowSeparator:first-child > td {
	border-top-color: transparent;
}
/* END "Table.less" */

/* START "TableSelectDialog.less" */
/* ======================================== */
/* CSS for control sap.m/TableSelectDialog  */
/* Fiori 3 theme                            */
/* ======================================== */

.sapMTableSelectDialog.sapUiResponsivePadding--content .sapMDialogScrollCont {

	&.sapUi-Std-PaddingS {
		padding-left: 0rem !important;
		padding-right: 0rem !important;
	}

	&.sapUi-Std-PaddingM,
	&.sapUi-Std-PaddingL {
		padding-left: 1rem !important;
		padding-right: 1rem !important;
	}

	&.sapUi-Std-PaddingXL {
		padding-left: 2rem !important;
		padding-right: 2rem !important;
	}
}
/* END "TableSelectDialog.less" */

/* START "TabStrip.less" */
/* =============================== */
/* CSS for control sap.m/TabStrip  */
/* Fiori 3 theme                   */
/* =============================== */

@_sap_m_TabStrip_ItemHoverTextColor: darken(@sapUiGroupTitleTextColor, 10);
@_sap_m_TabStrip_ItemSelectedTextColor: darken(@sapUiGroupTitleTextColor, 20);

.sapMTabStripContainer .sapMTabStrip {
	height: 3.25rem;
	background: var(--sapShell_Background);
	box-shadow: none;

	.sapMBtnBase {
		width: 2.25rem;
	}

	.sapMTSRightOverflowButtons {
		right: 5.8rem;
		text-align: center;

		.sapMBtn.sapMBtnBase {
			margin-left: 0;
			padding-left: 0;
		}
	}

	.sapMTSTabsContainer {
		left: 0;
		right: 5.8rem;

		.sapMTSTabs {

			.sapMTabStripItem {
				padding: 0 0 0 0.5rem;
				border-bottom: 0;
				margin-right: 0.5rem;

				&:last-child {
					margin-right: 0;
				}

				&:hover {
					color: @_sap_m_TabStrip_ItemHoverTextColor;
					background-color: var(--sapList_Hover_Background);
				}

				&.sapMTabStripItemSelected {
					color: var(--sapSelectedColor);
					background: var(--sapList_Background);
				}

				.sapMTSItemCloseBtnCnt {
					width: 2rem;
					height: 2.75rem;
					line-height: 2.5rem;

					.sapMBtn {
						width: 1.5rem;
						height: 2rem;
						vertical-align: middle;
					}
				}

				.sapMTabContIcon.sapUiIcon {
					color: var(--sapContent_IconColor);
				}
			}
		}
	}

	.sapMTSOverflowSelect {
		width: 2.25rem;
		height: 2.25rem;
	}

	.sapMTSLeftOverflowButtons {
		margin-left: 0;
	}
}

.sapMTabStripContainer {
	background: var(--sapShell_Background);
}

.sapMTSOverflowSelectListItem {
	padding-right: 0;
}

.sapMSltIcon.sapUiIcon.sapUiIconMirrorInRTL {
	font-size: 1rem;
}

.sapMTabStrip .sapMTSTabsContainer .sapMTSTabs .sapMTabStripItem:focus::before {
	top: 0.25rem;
}

.sapUiSizeCompact {

	.sapMTabStrip {

		.sapMTSRightOverflowButtons {
			right: 5.7rem;
		}

		.sapMTSTabsContainer .sapMTSTabs {

			.sapMTabStripItem {
				padding: 0 2rem 0 0.5rem;
				border-bottom: 0;

				&:hover {
					color: @_sap_m_TabStrip_ItemHoverTextColor;
					background-color: var(--sapList_Hover_Background);
					padding: 0 2rem 0 0.5rem;
				}

				&.sapMTabStripItemSelected {
					color: var(--sapSelectedColor);
					background: var(--sapList_Background);
					padding: 0 2rem 0 0.5rem;
				}

				.sapMTSItemCloseBtnCnt {
					width: 2rem;
					height: 2.75rem;

					.sapMBtn {
						width: 1.5rem;
						height: 2rem;
						opacity: 1;
					}
				}
			}
		}

		.sapMTSOverflowSelect {
			height: 1.625rem;
		}

		.sapMTSTouchArea .sapMSlt {
			margin-top: 0.46rem;
		}
	}

	.sapMTSOverflowSelectListItem .sapMTabStripSelectListItemCloseBtn {
		visibility: visible; /* close button must be always visible */
	}
}

.sapMTabStrip .sapMTSTabsContainer .sapMTSTabs .sapMTabStripItem.sapMTabStripItemSelected {
	box-shadow: inset 0 0.1875rem 0 var(--sapSelectedColor);
	border-bottom: 0;
	border-radius: 0.125rem 0.125rem 0 0;
}

html.sap-phone .sapMTabStripSelectListItemCloseBtn {
	margin-right: 1rem;
}

html[dir=ltr] .sapMTabStrip .sapMTSLeftOverflowButtons,
html[dir=rtl] .sapMTabStrip .sapMTSRightOverflowButtons {
	background: var(--sapShell_Background);
	width: 2.25rem;
}

html[dir=ltr] .sapMTabStrip .sapMTSLeftOverflowButtons::after,
html[dir=rtl] .sapMTabStrip .sapMTSRightOverflowButtons::after {
	background: transparent;
}

html[dir=ltr] .sapMTabStrip .sapMTSRightOverflowButtons,
html[dir=rtl] .sapMTabStrip .sapMTSLeftOverflowButtons {
	background: var(--sapShell_Background);
	width: 2.25rem;
}

html[dir=ltr] .sapMTabStrip .sapMTSRightOverflowButtons::after,
html[dir=rtl] .sapMTabStrip .sapMTSLeftOverflowButtons::after {
	background: transparent;
}

/* no animation for fiori 3 for acc reasons */
html[data-sap-ui-animation='on'] .sapMTabStrip .sapMTSTabsContainer .sapMTSTabs {

	.sapMTabStripItem,
	.sapMTabStripItem .sapMTSItemCloseBtnCnt .sapMBtn {
		transition: none;
	}
}

.sapMSltIconOnly.sapMSltHoverable:hover:not(.sapMSltState) {
	border: 0.0625rem solid var(--sapButton_Emphasized_Hover_BorderColor);
}
/* END "TabStrip.less" */

/* START "TabContainer.less" */
/* =================================== */
/* CSS for control sap.m/TabContainer  */
/* Fiori 3 theme                       */
/* =================================== */

.sapMTabStrip {
	padding-top: 0.5rem;
	height: 3.25rem;

	.sapMTSLeftOverflowButtons,
	.sapMTSTabsContainer,
	.sapMTSRightOverflowButtons,
	.sapMTSTouchArea {
		height: 2.75rem;
	}
}

.sapUiSizeCompact {

	.sapMTabStrip {
		height: 3.25rem;
	}
}
/* END "TabContainer.less" */

/* START "Text.less" */
/* =============================== */
/* CSS for control sap.m/Text      */
/* Fiori 3 theme                   */
/* =============================== */

/*Necessary to align vertically to Input */
.sapUiFormEdit .sapMText {
	min-height: 2.75rem; /* for empty text */
	padding-top: 0.6875rem;
	padding-bottom: 0.6875rem;
}

html[data-sap-ui-browser^='cr'] .sapUiFormEdit .sapMText {
	line-height: 1.4375rem;
}
/* END "Text.less" */

/* START "TextArea.less" */
/* =============================== */
/* CSS for control sap.m/TextArea  */
/* Fiori 3 theme                   */
/* =============================== */

/* uses sapMInputBase styles */
.sapMInputBase.sapMTextArea {
	min-height: 2.25rem;
}

html.sap-desktop:not(.sapUiNativeScrollbars) .sapMTextArea {

	.sapMInputBaseContentWrapperWarning ::-webkit-scrollbar {
		background: var(--sapField_WarningBackgroundStyle);
		background-color: var(--sapScrollBar_TrackColor);
	}

	.sapMInputBaseContentWrapperError ::-webkit-scrollbar {
		background: var(--sapField_InvalidBackgroundStyle);
		background-color: var(--sapScrollBar_TrackColor);
	}

	.sapMInputBaseContentWrapperInformation ::-webkit-scrollbar {
		background: var(--sapField_InformationBackgroundStyle);
		background-color: var(--sapScrollBar_TrackColor);
	}

	.sapMInputBaseContentWrapperSuccess ::-webkit-scrollbar {
		background: var(--sapField_SuccessBackgroundStyle);
		background-color: var(--sapScrollBar_TrackColor);
	}
}
/* END "TextArea.less" */

/* START "TileContent.less" */
/* ================================== */
/* CSS for control sap.m/TileContent  */
/* Fiori 3 theme                  */
/* ================================== */

@_sap_m_TileContent_NewsContentBackgroundColor: var(--sapTile_OverlayBackground);
@_sap_m_TileContent_NewsFooterTextColor: @_sap_m_NewsContent_SubHeaderTextColor;

.sapMTileCnt.News {
	background-color: @_sap_m_TileContent_NewsContentBackgroundColor;
	opacity: 0.8;
}

.sapMTileCnt.News .sapMTileCntFtrTxt {
	color: @_sap_m_TileContent_NewsFooterTextColor;
}
/* END "TileContent.less" */

/* START "TileContainer.less" */
/* ==================================== */
/* CSS for control sap.m/TileContainer  */
/* Fiori 3 theme                        */
/* ==================================== */

.sapMTC .sapMTCBlind {
	opacity: 0.4;
}

.sapMTC .sapMTCScroller:focus::before {
	border: 1px dotted var(--sapContent_FocusColor);
	position: absolute;
	top: -1px;
	bottom: -1px;
	left: -1px;
	right: -1px;
}
/* END "TileContainer.less" */

/* START "TimePicker.less" */
/* ================================= */
/* CSS for control sap.m/TimePicker  */
/* Fiori 3 theme                     */
/* ================================= */

@_sap_m_TimePicker_ItemColor: var(--sapLegend_WorkingBackground);
@_sap_m_TimePicker_ItemHoverColor: var(--sapList_Hover_Background);
@_sap_m_TimePicker_ItemBorderColor: var(--sapList_Background);
/* END "TimePicker.less" */

/* START "TimePickerSliders.less" */
/* ======================================== */
/* CSS for control sap.m/TimePickerSliders  */
/* Fiori 3 theme                            */
/* ======================================== */

/* TimePicker Dropdown */
.sapMTimePickerSlider {

	.sapMTimePickerItem {
		border-radius: var(--sapButton_BorderCornerRadius);
	}
}

.sapMTimePickerContainer {

	.sapMTPColumn:not(:last-child),
	.sapMTPColumn.sapMTPSliderExpanded:not(:last-child) {
		margin-right: 0.5rem;
	}
}

.sapMTimePickerContainer .sapMTPColumn {

	.sapMTimePickerSlider,
	.sapMTimePickerLabel,
	.sapMTimePickerSlider {

		.sapMTimePickerItem,
		.sapMTPPickerSelectionFrame,
		.sapMTPSliderExpanded {
			width: 3rem;
			height: 2.875rem;
		}

		width: 3rem;
		height: 2.875rem;
	}
}

.sapUiSizeCompact .sapMTimePickerContainer .sapMTPColumn {

	.sapMTimePickerSlider,
	.sapMTimePickerLabel,
	.sapMTimePickerSlider {

		.sapMTimePickerItem,
		.sapMTPPickerSelectionFrame,
		.sapMTPSliderExpanded {
			width: 3rem;
		}

		width: 3rem;
		height: 2rem;
	}
}

.sapMTimePickerContainer {

	.sapMTPColumn {

		.sapMTimePickerSlider {

			.sapMTimePickerItem {
				background: var(--sapContent_Selected_Background);
				border: 1px solid var(--sapList_Background);

				&:hover {
					background: var(--sapContent_Selected_Hover_Background);
				}
			}
		}

		&.sapMTPSliderExpanded {

			.sapMTimePickerSlider {

				.sapMTimePickerItem {
					background: var(--sapLegend_WorkingBackground);
					border: 0.0625rem solid var(--sapList_Background);

					&:hover {
						background: var(--sapList_Hover_Background);
					}

					&:active {
						background: var(--sapContent_Selected_Background);
						color: var(--sapContent_Selected_TextColor);
					}

	 				&.sapMTimePickerItemSelected {
						background: var(--sapList_Background)
					}
				}

				.sapMTPPickerSelectionFrame {
					border: 0.0625rem solid var(--sapList_SelectionBorderColor);
					border-radius: var(--sapButton_BorderCornerRadius);
					outline:none;

					&:hover {

						+ ul > li.sapMTimePickerItem.sapMTimePickerItemSelected {
							background: var(--sapList_Hover_Background);
						}
					}

					&:active {

						& + ul > li.sapMTimePickerItem.sapMTimePickerItemSelected {
							background: var(--sapContent_Selected_Background);
							color: var(--sapContent_Selected_TextColor);
						}
					}
				}
			}
		}
	}

	.sapMTPDisabled {
		opacity: 0.5;
	}
}

/* PHONE STYLES */
.sap-phone {

	/* TimePicker Dropdown */
	.sapMTimePickerContainer {

		.sapMTPColumn {

			.sapMTimePickerSlider,
			.sapMTimePickerLabel,
			.sapMTimePickerSlider {

				.sapMTimePickerItem,
				.sapMTPPickerSelectionFrame,
				.sapMTPSliderExpanded {
					width: 3rem;
					height: 2.875rem;
				}

				width: 3rem;
				height: 2.875rem;
			}

			.sapMTimePickerSlider {

				.sapMTimePickerItem {
					border: 1px solid var(--sapList_Background);
				}
			}

			&.sapMTPSliderExpanded {

				.sapMTimePickerSlider {

					.sapMTimePickerItem {
						background: var(--sapLegend_WorkingBackground);
						border: 1px solid var(--sapList_Background);
						width: 3rem;
					}

					.sapMTPPickerSelectionFrame {
						outline: 0.125rem solid var(--sapSelectedColor);
						outline-offset: -0.188rem;
					}
				}
			}
		}
	}
}
/* END "TimePickerSliders.less" */

/* START "ToggleButton.less" */
/* ==================================== */
/* CSS for control sap.m/ToggleButton   */
/* Fiori 3 theme                        */
/* ==================================== */

/* hover and down on toggled button */
.sapMBtn:hover > .sapMBtnHoverable.sapMToggleBtnPressed:not(.sapMBtnActive),
.sapMBtn .sapMBtnHoverable.sapMToggleBtnPressed:hover {

	&.sapMBtnReject {
		background-color: var(--sapButton_Reject_Selected_Hover_Background);
		border-color: var(--sapButton_Reject_Selected_Hover_BorderColor);
		color: var(--sapButton_Reject_Selected_TextColor);

		& .sapUiIcon {
			color: var(--sapButton_Reject_Selected_TextColor);
		}
	}

	&.sapMBtnAccept {
		background-color: var(--sapButton_Accept_Selected_Hover_Background);
		border-color: var(--sapButton_Accept_Selected_Hover_BorderColor);
		color: var(--sapButton_Accept_Selected_TextColor);

		& .sapUiIcon {
			color: var(--sapButton_Accept_Selected_TextColor);
		}
	}

	&.sapMBtnAttention {
		background-color: var(--sapButton_Attention_Selected_Hover_Background);
		border-color: var(--sapButton_Attention_Selected_Hover_BorderColor);
		color: var(--sapButton_Attention_Selected_TextColor);

		& .sapUiIcon {
			color: var(--sapButton_Attention_Selected_TextColor);
		}
	}
}
/* END "ToggleButton.less" */

/* START "Token.less" */
/* ============================ */
/* CSS for control sap.m/Token  */
/* Fiori 3 theme                */
/* ============================ */

@_sap_m_Token_TokenPadding: 0.5rem;
@_sap_m_Token_TokenCompactPadding: 0.25rem;
@_sap_m_Token_LeftPadding: 0.3125rem;
@_sap_m_Token_IconWidth: 1.75rem;
@_sap_m_Token_CompactIconWidth: 1.5rem;
@_sap_m_Token_DeleteIconHeight: 2.25rem;
@_sap_m_Token_DeleteIconCompactHeight: 1.625rem;

.sapMToken {
	padding-left: 0.3125rem;
	color: @sapUiBaseText;
	overflow: visible;
}

html.sap-desktop .sapMToken.sapMTokenSelected:not(.sapMTokenReadOnly):hover {
	background: @sapUiButtonSelectedHoverBackground;
	border: @sapUiButtonBorderWidth solid @sapUiButtonSelectedHoverBorderColor;
}

.sapMToken.sapMTokenReadOnly {
	color: @sapUiContentLabelColor
}

html.sap-desktop .sapMToken:focus {
	outline: @sapUiContentFocusWidth @sapUiContentFocusStyle @sapUiContentFocusColor;
	outline-offset: -0.1875rem;
}

html.sap-desktop .sapMToken.sapMTokenSelected:focus {
	outline: @sapUiContentFocusWidth @sapUiContentFocusStyle @sapUiContentContrastFocusColor;
}

.sapMTokenIcon {
	box-sizing: border-box;
	top: ~"calc((@{_sap_m_Token_TokenHeight} / 2) - (@{_sap_m_Token_DeleteIconHeight} / 2) - @{sapUiButtonBorderWidth})";
	width: @_sap_m_Token_IconWidth;
	height: @_sap_m_Token_DeleteIconHeight;
	display: inline-flex;
	justify-content: center;
	align-items: center;
}

.sapUiSizeCompact .sapMTokenIcon {
	top: ~"calc((@{_sap_m_Token_TokenCompactHeight} / 2) - (@{_sap_m_Token_DeleteIconCompactHeight} / 2) - @{sapUiButtonBorderWidth})";
	width: @_sap_m_Token_CompactIconWidth;
	height: @_sap_m_Token_DeleteIconCompactHeight;
}

.sapMTokenIcon::before {
	display: inline-block;
	width: 0.75rem;
	height: 0.75rem;
	line-height: 1;
}
/* END "Token.less" */

/* START "Tokenizer.less" */
/* ================================ */
/* CSS for control sap.m/Tokenizer  */
/* Fiori 3 theme                    */
/* ================================ */

@_sap_m_Tokenizer_OutlineOffset: -0.1875rem;

.sapMTokenizer {
	padding-left: 0.3125rem;
	position: relative;
	display: inline-block;
	white-space: nowrap;
	overflow: hidden;
	box-sizing: border-box;
}

.sapMTokenizer .sapMToken {
	margin-right: 0.3125rem;
	max-width: calc(~"100% - 0.3125rem");
	margin-top: 0.25rem;
}

html.sap-desktop .sapMTokenizer:focus {
	outline: @sapUiContentFocusWidth @sapUiContentFocusStyle @sapUiContentFocusColor;
	outline-offset: @_sap_m_Tokenizer_OutlineOffset;
}

/* editable tokens in read-only tokenizer */
.sapMTokenizer.sapMTokenizerReadonly {
	.sapMToken {
		color: @sapUiContentLabelColor;

		&.sapMTokenSelected {
			color: @sapUiToggleButtonPressedTextColor;
		}
	}
}

.sapUiSizeCompact {
	.sapMTokenizer {
		padding-left: 0.25rem;
	}
}

/* ------------------------------ */
/* Disabled                       */
/* ------------------------------ */

.sapMTokenizer.sapMTokenizerDisabled .sapMToken  {
  &.sapMToken:hover,
  &.sapMToken:focus,
  &.sapMTokenSelected,
  &.sapMToken.sapMTokenSelected:hover {
    background: darken(@sapUiButtonBackground, 2);
    cursor: default;
    color: @sapUiBaseText;
    outline: none;
    border: 1px solid darken(@sapUiButtonBackground, 24);
  }

  &.sapMTokenSelected .sapMTokenText {
    color: @sapUiBaseText;
  }

  &.sapMTokenSelected .sapMTokenIcon {
    color: @sapUiContentIconColor;
    cursor: default;
  }

  & .sapMTokenIcon {
    cursor: default;
  }
}
/* END "Tokenizer.less" */

/* START "Toolbar.less" */
/* ============================== */
/* CSS for control sap.m/Toolbar  */
/* Fiori 3 theme                  */
/* ============================== */

html.sap-desktop .sapMTBActive:focus,
html.sap-desktop .sapMTBActive.sapMTBFocused {
	outline: 0.0625rem dotted @sapUiContentFocusColor;
	outline-offset: -0.1875rem;
}

.sapMTB {
	height: 2.75rem;
	padding: 0 0.5rem;
	background: @sapUiToolbarBackground;
}

.sapMIBar > .sapMBarChild:last-child {
	margin-right: 0;
}

/* Transparent Toolbar Context */
.sapMTB-Transparent-CTX.sapMTB {
	padding-left: 0.5rem;
}

/* Info Toolbar Context */
.sapMIBar.sapMTB.sapMTB-Info-CTX {
	padding-left: 0.5rem;
}

/* Solid Toolbar Context */
.sapMTB-Solid-CTX.sapMTB {
	background: @sapUiBaseBG;
}

/* Info Toolbar Context */
.sapMTB-Info-CTX.sapMTB {
	background: darken(@sapUiBaseColor, 10);

	> .sapUiIcon {
		color: @sapUiBaseText;
	}

	> .sapUiIcon:focus {
		color: @sapUiContentFocusWidth @sapUiContentFocusStyle @sapContent_FocusColor;
	}

	&.sapMTBActive {
		background: @sapUiInfobarBackground;
		.generate-contrast-color-toolbar(@sapUiInfobarBackground);

		&:active {
			.generate-contrast-color-toolbar(@sapUiInfobarActiveBackground);
		}

		&:hover {
			.generate-contrast-color-toolbar(@sapUiInfobarHoverBackground);
		}

		.sapMText,
		.sapMLabel,
		> .sapMTitle,
		> .sapUiIcon {
			color: inherit;
		}
	}
}

html.sap-desktop .sapMTB-Info-CTX.sapMTBActive.sapMTBFocused {
	outline-color: @sapUiContentContrastFocusColor;
}

.generate-contrast-color-toolbar(@backgroundColor) {
	color: contrast(@backgroundColor, @sapUiBaseText, @sapUiContentContrastTextColor, @sapUiContentContrastTextThreshold);
}
/* END "Toolbar.less" */

/* START "UploadCollection.less" */
/* ======================================= */
/* CSS for control sap.m/UploadCollection  */
/* Fiori 3 theme                           */
/* ======================================= */

.sapMLIB.sapMUCListSingleItem,
.sapMLIB.sapMUCListFirstItem,
.sapMLIB.sapMUCListLastItem,
.sapMLIB.sapMUCListItem {
	border-bottom-color: @sapUiListBorderColor;
}
/* END "UploadCollection.less" */

/* START "ValueStateMessage.less" */
/* ======================================== */
/* CSS for control sap.m/ValueStateMessage  */
/* Fiori 3 theme                            */
/* ======================================== */

.sapMValueStateMessage {
	border-width: 0;
}
/* END "ValueStateMessage.less" */

/* START "ViewSettingsDialog.less" */
/* ========================================= */
/* CSS for control sap.m/ViewSettingsDialog  */
/* Fiori 3 theme                             */
/* ========================================= */

@_sap_m_ViewSettingsDialog_HeaderBorderColor: darken(@sapUiGroupContentBackground, 8);

.sapMVSD .sapMPageHeader {
	z-index: 2;

	.sapMBarTitleStart .sapMBarPH {
		padding-left: 0rem;
	}
}

.sapMTB.sapMVSDFilterHeaderToolbar {
	background-color: var(--sapGroup_ContentBackground);
	border-bottom: 1px solid @_sap_m_ViewSettingsDialog_HeaderBorderColor;
	padding-left: 0;

	.sapMBarChild.sapMCb {

		.sapMCbLabel {
			font-family: var(--sapFontFamily);
			color: var(--sapGroup_TitleTextColor);
		}
	}
}

.sapMVSD.sapMDialog.sapMPopup-CTX .sapMIBar.sapMHeader-CTX,
.sapMVSD.sapMDialog.sapMPopup-CTX .sapMIBar.sapMSubHeader-CTX {
	background-color: var(--sapGroup_ContentBackground);
}

.sapMVSD .sapMVSDBar {
	box-shadow: @sapUiShadowHeader;
}

.sapMVSDBarWithSearch.sapMBar,
.sapMVSD.sapMDialog.sapMPopup-CTX .sapMIBar.sapMHeader-CTX .sapMVSDBarWithSearch,
.sapMVSD.sapMDialog.sapMPopup-CTX .sapMIBar.sapMSubHeader-CTX .sapMVSDBarWithSearch {
	box-shadow: none;
}

.sapMVSD .sapMPageWithSubHeader .sapMIBar.sapMHeader-CTX {
	border-bottom: none;
	box-shadow: none;
}
/* END "ViewSettingsDialog.less" */

/* START "WheelSlider.less" */
/* ================================== */
/* CSS for control sap.m/WheelSlider  */
/* Fiori 3 theme                      */
/* ================================== */

@_sap_m_TimePicker_ItemColor: darken(@sapUiListBackground, 3);
@_sap_m_TimePicker_ItemHoverColor: darken(@sapUiListBackground, 6);
@_sap_m_TimePicker_ItemBorderColor: var(--sapList_Background);

.sapMWS:not(:last-child),
.sapMWS.sapMWSExpanded:not(:last-child) {
	margin-right: 0.5rem;
}

.sapMWS {

	.sapMWSLabel,
	.sapMWSInner {
		width: 3rem;
		height: 2.875rem;

		.sapMWSItem,
		.sapMWSSelectionFrame {
			width: 3rem;
			height: 2.875rem;
		}

		.sapMWSItem {
			border-radius: 0.25rem;
			background: var(--sapActiveColor);
			border: 1px solid @_sap_m_TimePicker_ItemBorderColor;

			&:hover {
				background: darken(@sapUiSelected, 10);
			}
		}
	}

	&.sapMWSExpanded {

		.sapMWSInner {

			.sapMWSItem {
				background: @_sap_m_TimePicker_ItemColor;
				border: 1px solid @_sap_m_TimePicker_ItemBorderColor;

				&:hover {
					background: @_sap_m_TimePicker_ItemHoverColor;
				}

				&:active {
					background: var(--sapActiveColor);
					color: var(--sapContent_ContrastTextColor);
				}
			}

			.sapMWSSelectionFrame {
				border: 0.125rem solid var(--sapSelectedColor);
				border-radius: 0.25rem;
				outline:none;

				&:hover {

					+ ul > li.sapMWSItem.sapMWSItemSelected {
						background: @_sap_m_TimePicker_ItemHoverColor;
					}
				}

				&:active {

					& + ul > li.sapMWSItem.sapMWSItemSelected {
						background: var(--sapActiveColor);
						color: var(--sapContent_ContrastTextColor);
					}
				}
			}
		}
	}
}

.sapUiSizeCompact .sapMWS {

	.sapMWSLabel,
	.sapMWSInner {
		width: 3rem;
		height: 2rem;

		.sapMWSItem,
		.sapMWSSelectionFrame,
		.sapMWSExpanded {
			width: 3rem;
		}
	}
}

.sap-phone {

	.sapMWS {

		.sapMWSLabel,
		.sapMWSInner {
			width: 3rem;
			height: 2.875rem;

			.sapMWSItem,
			.sapMWSSelectionFrame {
				width: 3rem;
				height: 2.875rem;
			}

			.sapMWSItem {
				border: 1px solid @_sap_m_TimePicker_ItemBorderColor;
			}
		}

		&.sapMWSExpanded {

			.sapMWSInner {

				.sapMWSItem {
					background: @_sap_m_TimePicker_ItemColor;
					border: 1px solid @_sap_m_TimePicker_ItemBorderColor;
					width: 3rem;
				}

				.sapMWSSelectionFrame {
					outline: 0.125rem solid var(--sapSelectedColor);
					outline-offset: -0.188rem;
				}
			}
		}
	}
}
/* END "WheelSlider.less" */

/* START "Wizard.less" */
/* ============================= */
/* CSS for control sap.m/Wizard  */
/* Fiori 3 theme                 */
/* ============================= */

.sapMWizard {
	.sapMWizardStepContainer {
		margin-top: @_sap_m_Wizard_NavHeight;
	}

	&.sapMWizardBgSolid .sapMWizardStepContainer {
		background-color: @sapUiShellBackground;
	}
}
.sapMWizard .sapMWizardProgressNav {
	box-shadow: @sapUiShadowHeader;
}

.sapMWizard {
	overflow: hidden;
}

html.sap-phone .sapMWizard .sapMWizardNextButtonVisible {
	left: 1rem;
	bottom: 3.5rem;
	-webkit-transform: none;
	transform: none;
}
/* END "Wizard.less" */

/* START "WizardProgressNavigator.less" */
/* ============================================== */
/* CSS for control sap.m/WizardProgressNavigator  */
/* Fiori 3 theme                                  */
/* ============================================== */

@_sap_m_WizardProgressNavigator_StepUnderlineHeight: 0.188rem;
@_sap_m_WizardProgressNavigator_BoxShadow: 0.0625rem;

.sapMWizardProgressNav {
	position: absolute;
	z-index: 1;
}

.sapMWizardProgressNavStep:hover .sapMWizardProgressNavStepCircle {
	background-color: @sapUiObjectHeaderBackground;
	color: @sapUiHighlight;
}

.sapMWizardProgressNavStep[data-sap-ui-wpn-step-current="true"]:hover .sapMWizardProgressNavStepCircle {
	background-color: @sapUiHighlight;
	color: @sapUiContentContrastIconColor;
}

.sapMWizardProgressNavStep[data-sap-ui-wpn-step-current="true"]:hover .sapMWizardProgressNavStepTitle,
.sapMWizardProgressNavStep:hover .sapMWizardProgressNavStepTitle {
	color: @sapUiContentLabelColor;
}

.sapMWizardProgressNavStep[data-sap-ui-wpn-step-current="true"] .sapMWizardProgressNavStepCircle::after {
	height: @_sap_m_WizardProgressNavigator_StepUnderlineHeight;
	background: @sapUiSelected;
	content: "";
	display: block;
	position: relative;
	width: 100%;
	border-top-left-radius: 0.125rem;
	border-top-right-radius: 0.125rem;
	bottom: -0.75rem;
}

.sapMWizardProgressNavStep[data-sap-ui-wpn-step-current="true"] .sapMWizardProgressNavStepContainer::after {
	height: 0;
}
.sapMWizardProgressNavStep[data-sap-ui-wpn-step-current="true"] {
	& .sapMWizardProgressNavStepCircle {
		background: @sapUiSelected;
		color: @sapUiContentContrastTextColor;
	}
}

.sapMWizardProgressNavStepCircle {
	background: @sapUiObjectHeaderBackground;
	border-color:  @sapUiSelected;
	color: @sapUiSelected;
}

.sapMWizardProgressNavStepTitle {
	color: @sapUiContentLabelColor;
}

.sapMWizardProgressNavStepTitle:hover {
	color: @sapUiContentLabelColor;
}

.sapMWizardProgressNavStep::after {
	border-bottom-color: @sapUiSelected;
}

.sapMWizard .sapMWizardStepContainer {
  background: @sapUiGroupContentBackground;
}

.sapMWizardProgressNavStepTitleOptional,
.sapMWizardProgressNavStepLabelOptional {
	color: @sapUiFieldPlaceholderTextColor;
}

.sapMWizardProgressNavStep[data-sap-ui-wpn-step-active="true"] {
	/* all steps after the active one have inactive style */
	& ~ .sapMWizardProgressNavStep .sapMWizardProgressNavStepCircle {
		border-color: @sapUiListBorderColor;
		background: @sapUiObjectHeaderBackground;
		color: @sapUiContentLabelColor;
	}

	/* all separators after (and including) the active step have inactive style */
	&::after,
	& ~ .sapMWizardProgressNavStep::after {
		border-bottom-color: @sapUiListBorderColor;
	}
}

.sapMWizardProgressNavStep[data-sap-ui-wpn-step-open-prev="true"][data-sap-ui-wpn-step-open="false"][data-sap-ui-wpn-step-current="true"] {
	.sapMWizardProgressNavStepCircle {
		background: @sapUiActive;
		border-color: @sapUiActive;
	}
}
/* END "WizardProgressNavigator.less" */
